@@ -1,19 +1,18 @@
-/* BEAST - Bedevilled Audio System
+/* BEAST - Better Audio System
  * Copyright (C) 1998-2002 Tim Janik
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "topconfig.h"
 #include "bstapp.h"
@@ -71,7 +70,6 @@ enum {
   ACTION_URL_REPORT_BUG,
   ACTION_URL_ONLINE_SYNTHESIZERS,
   ACTION_URL_ONLINE_DEMOS,
-  ACTION_DEMO_DIALOG_FATAL,
   ACTION_DEMO_DIALOG_ERROR,
   ACTION_DEMO_DIALOG_WARNING,
   ACTION_DEMO_DIALOG_SCRIPT,
@@ -92,7 +90,7 @@ static const GxkStockAction file_open_actions[] = {
     BST_ACTION_CLOSE_PROJECT,   BST_STOCK_CLOSE, },
 };
 static const GxkStockAction file_save_actions[] = {
-  { N_("_Save"),                NULL,           N_("Write project to disk"),
+  { N_("_Save"),                "<ctrl>S",      N_("Write project to disk"),
     BST_ACTION_SAVE_PROJECT,    BST_STOCK_SAVE, },
   { N_("Save _As..."),          NULL,           N_("Write project to a specific file"),
     BST_ACTION_SAVE_PROJECT_AS, BST_STOCK_SAVE_AS, },
@@ -135,7 +133,7 @@ static const GxkStockAction dialog_actions[] = {
 static const GxkStockAction playback_actions[] = {
   { N_("_Play"),                "<ctrl>P",      N_("Play or restart playback of the project"),
     BST_ACTION_START_PLAYBACK,  BST_STOCK_PLAY },
-  { N_("_Stop"),                "<ctrl>S",      N_("Stop playback of the project"),
+  { N_("_Stop"),                "<ctrl>D",      N_("Stop playback of the project"),
     BST_ACTION_STOP_PLAYBACK,  BST_STOCK_STOP },
 };
 static const GxkStockAction project_actions[] = {
@@ -191,8 +189,6 @@ static const GxkStockAction online_demos[] = {
     ACTION_URL_ONLINE_DEMOS,        BST_STOCK_ONLINE_SOUND_ARCHIVE },
 };
 static const GxkStockAction demo_dialogs[] = {
-  { "Demo Fatal Error Dialog",  NULL,           "Fire up a fatal error dialog for demonstration purposes",
-    ACTION_DEMO_DIALOG_FATAL,   BST_STOCK_ERROR },
   { "Demo Error Dialog",        NULL,           "Fire up an error dialog for demonstration purposes",
     ACTION_DEMO_DIALOG_ERROR,   BST_STOCK_ERROR },
   { "Demo Warning Dialog",      NULL,           "Fire up a warning dialog for demonstration purposes",
@@ -1071,7 +1067,7 @@ app_action_exec (gpointer data,
       docs_title = "BEAST FAQ";
       goto BROWSE_LOCAL_URL;
     case ACTION_HELP_QUICK_START:
-      docs_url = "html/quickstart.html";
+      docs_url = "html/Beast-Quickstart";
       docs_title = "BEAST Quick Start Guide";
       goto BROWSE_LOCAL_URL;
     case ACTION_HELP_RELEASE_NOTES:
@@ -1094,7 +1090,7 @@ app_action_exec (gpointer data,
       if (docs_url)
         {
           gchar *local_url = g_strconcat ("file://", BST_PATH_DOCS, "/", docs_url, NULL);
-          birnet_url_show_with_cookie (local_url, docs_title, self->cookie);
+          sfi_url_show_with_cookie (local_url, docs_title, self->cookie);
           g_free (local_url);
         }
       break;
@@ -1102,21 +1098,20 @@ app_action_exec (gpointer data,
       beast_show_about_box ();
       break;
     case ACTION_URL_HELP_DESK:
-      birnet_url_show ("http://beast.gtk.org/wiki:HelpDesk");
+      sfi_url_show ("http://beast.testbit.eu/Beast_Help_Desk");
       break;
     case ACTION_URL_BEAST_SITE:
-      birnet_url_show ("http://beast.gtk.org/");
+      sfi_url_show ("http://beast.testbit.eu/");
       break;
     case ACTION_URL_REPORT_BUG:
-      birnet_url_show ("http://bugzilla.gnome.org/simple-bug-guide.cgi?product=beast");
+      sfi_url_show ("https://bugzilla.gnome.org/enter_bug.cgi?product=beast");
       break;
     case ACTION_URL_ONLINE_SYNTHESIZERS:
-      birnet_url_show ("http://beast.gtk.org/sound-browser");
+      sfi_url_show ("http://beast.testbit.eu/Beast_Sound_Gallery");
       break;
     case ACTION_URL_ONLINE_DEMOS:
-      birnet_url_show ("http://beast.gtk.org/sound-browser");
+      sfi_url_show ("http://beast.testbit.eu/Beast_Sound_Gallery");
       break;
-    case ACTION_DEMO_DIALOG_FATAL:
     case ACTION_DEMO_DIALOG_ERROR:
     case ACTION_DEMO_DIALOG_WARNING:
     case ACTION_DEMO_DIALOG_SCRIPT:
@@ -1126,7 +1121,6 @@ app_action_exec (gpointer data,
       switch (action)
         {
         default: /* silence compiler */
-        case ACTION_DEMO_DIALOG_FATAL:   demo_type = BST_MSG_FATAL;   break;
         case ACTION_DEMO_DIALOG_ERROR:   demo_type = BST_MSG_ERROR;   break;
         case ACTION_DEMO_DIALOG_WARNING: demo_type = BST_MSG_WARNING; break;
         case ACTION_DEMO_DIALOG_SCRIPT:  demo_type = BST_MSG_SCRIPT;  break;
@@ -1135,13 +1129,13 @@ app_action_exec (gpointer data,
         case ACTION_DEMO_DIALOG_DEBUG:   demo_type = BST_MSG_DEBUG;   break;
         }
       bst_msg_dialog (demo_type,
-                      BIRNET_MSG_TEXT0 ("Demonstration Dialog"),
-                      BIRNET_MSG_TEXT1 ("This is a demonstrative dialog"),
-                      BIRNET_MSG_TEXT2 ("To help with dialog layout, and to test message display, dialogs may be "
+                      BST_MSG_TEXT0 ("Demonstration Dialog"),
+                      BST_MSG_TEXT1 ("This is a demonstration dialog"),
+                      BST_MSG_TEXT2 ("To help with dialog layout, and to test message display, dialogs may be "
                                      "fired up for pure demonstration purposes. This is such a dialog, so if you "
                                      "are currently looking at a prominent warning or error message, there's no "
                                      "real merit to it."),
-                      BIRNET_MSG_TEXT3 ("Demo-Dialog-Type: %s", birnet_msg_type_label (demo_type)));
+                      BST_MSG_TEXT3 ("Demo-Dialog-Type: %s", sfi_msg_type_label (demo_type)));
       break;
     default:
       g_assert_not_reached ();
@@ -1229,7 +1223,6 @@ app_action_check (gpointer data,
     case ACTION_URL_REPORT_BUG:
     case ACTION_URL_ONLINE_SYNTHESIZERS:
     case ACTION_URL_ONLINE_DEMOS:
-    case ACTION_DEMO_DIALOG_FATAL:
     case ACTION_DEMO_DIALOG_ERROR:
     case ACTION_DEMO_DIALOG_WARNING:
     case ACTION_DEMO_DIALOG_SCRIPT:
