@@ -1,20 +1,18 @@
-/* BEAST - Bedevilled Audio System
+/* BEAST - Better Audio System
  * Copyright (C) 2004 Tim Janik
  *
- * This program is free software; you can redistribute it and/or
+ * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "topconfig.h"  /* BST_PATH_KEYS */
 #include "bstkeybindings.h"
@@ -150,7 +148,7 @@ key_bindings_exec_action (gpointer data,
 #endif
         }
       else
-        gdk_beep();
+        bst_gui_error_bell (self);
       break;
     case ACTION_EDIT:
       tsel = gtk_tree_view_get_selection (btview);
@@ -172,7 +170,7 @@ key_bindings_exec_action (gpointer data,
           gxk_list_wrapper_notify_change (GXK_LIST_WRAPPER (model), nb);
         }
       else
-        gdk_beep();
+        bst_gui_error_bell (self);
       break;
     case ACTION_LOWER:
       tsel = gtk_tree_view_get_selection (btview);
@@ -313,7 +311,7 @@ key_binding_binding_param_edited (GtkWidget   *self,
       if (error)
         {
           g_free (error);
-          gdk_beep();
+          bst_gui_error_bell (self);
           return;
         }
     }
