@@ -1,21 +1,21 @@
-/* BEAST - Bedevilled Audio System
+/* BEAST - Better Audio System
  * Copyright (C) 1998-2003 Tim Janik
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bstutils.h"
+#include "bstcxxutils.h"
 #include "bse/bse.h"
 #include "bstapp.h"
 #include "bstsplash.h"
@@ -85,7 +85,7 @@ main (int   argc,
   gchar *string;
   GSource *source;
   char debugbool[2] = "0";
-  BirnetInitValue config[] = {
+  SfiInitValue config[] = {
     { "debug-extensions", debugbool },
     { NULL },
   };
@@ -109,11 +109,11 @@ main (int   argc,
   g_type_init ();
 
   /* initialize Birnet/Sfi */
-  birnet_init (&argc, &argv, _("BEAST"));  /* application name is user visible */       
-  birnet_msg_allow ("misc");
+  sfi_init (&argc, &argv, _("BEAST"), NULL);  /* application name is user visible */       
+  sfi_msg_allow ("misc");
   /* ensure SFI can wake us up */
-  birnet_thread_set_name ("Beast GUI");
-  birnet_thread_set_wakeup ((BirnetThreadWakeup) g_main_context_wakeup,
+  sfi_thread_set_name ("Beast GUI");
+  sfi_thread_set_wakeup ((BirnetThreadWakeup) g_main_context_wakeup,
 			 g_main_context_default (), NULL);
 
   /* initialize Gtk+ and go into threading mode */
@@ -136,7 +136,7 @@ main (int   argc,
   gtk_object_set_user_data (GTK_OBJECT (beast_splash), NULL);	/* fix for broken user_data in 2.2 */
   bst_splash_set_text (beast_splash,
 		       "<b><big>BEAST</big></b>\n"
-		       "<b>The Bedevilled Audio System</b>\n"
+		       "<b>The Better Audio System</b>\n"
 		       "<b>Version %s (%s)</b>\n",
 		       BST_VERSION, BST_VERSION_HINT);
   bst_splash_update_entity (beast_splash, _("Startup"));
@@ -257,7 +257,7 @@ main (int   argc,
   _bst_init_radgets ();
 
   /* install message dialog handler */
-  birnet_msg_set_thread_handler (bst_message_log_handler);
+  bst_message_handler_install();
 
   /* open files given on command line */
   if (argc > 1)
@@ -358,26 +358,25 @@ main (int   argc,
         "<tagdef name=\"title\" weight=\"bold\" scale=\"1.5\"/>"
         "<tagdef name=\"hyperlink\" underline=\"single\" foreground=\"#0000ff\"/>"
         "<tagdef name=\"mono\" family=\"monospace\"/>"
-        "<span tag=\"title\">BEAST/BSE Release Notes</span>"
+        "<span tag=\"title\">BEAST/BSE " BST_VERSION " Release Notes</span>"
         "<newline/><newline/>"
         "The 0.7 development series of Beast focusses on improving usability and ease of music production. "
         "<newline/><newline/>"
         "Feedback is very much appreciated, please take the opportunity and provide your comments "
         "and questions in online forums like the Beast "
-        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/wiki:HelpDesk\">Help Desk</xlink></span>, Beast "
         "<span tag=\"hyperlink\"><xlink ref=\"http://bugzilla.gnome.org/buglist.cgi?query=product:beast\">Bugzilla</xlink></span> "
         "or the "
-        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/contact\">mailing list</xlink></span>, "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.testbit.eu/Beast_Contact\">mailing list</xlink></span>, "
         "all of which can be reached through the links provided by the Help/ menu."
         "<newline/><newline/>"
-        "The Beast website also provides much more information like detailed "
-        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/news-file\">release NEWS</xlink></span>, "
+        "The Beast website provides much more information like detailed "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.testbit.eu/Beast_News\">project news</xlink></span>, "
         "synthesis hints, documentation and a "
-        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/sound-browser\">sound archive</xlink></span>. "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.testbit.eu/Beast_Sound_Gallery\">sound archive</xlink></span>. "
         "<newline/>"
         "So either activate 'Help/Beast Website...' or go to:"
         "<newline/>"
-        "<span tag=\"mono\">        </span><span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org\">http://beast.gtk.org</xlink></span>"
+        "<span tag=\"mono\">        </span><span tag=\"hyperlink\"><xlink ref=\"http://beast.testbit.eu/\">http://beast.testbit.eu</xlink></span>"
         "</tag-span-markup>";
       GtkWidget *sctext = gxk_scroll_text_create (GXK_SCROLL_TEXT_WRAP | GXK_SCROLL_TEXT_SANS | GXK_SCROLL_TEXT_CENTER, NULL);
       gxk_scroll_text_set_tsm (sctext, release_notes_contents);
@@ -402,7 +401,7 @@ main (int   argc,
     }
   
   /* take down GUI */
-  birnet_msg_set_thread_handler (NULL);
+  bst_message_handler_uninstall();
   bst_message_dialogs_popdown ();
   
   /* perform necessary cleanup cycles */
@@ -455,16 +454,16 @@ bst_early_parse_args (int    *argc_p,
   
   envar = getenv ("BST_DEBUG");
   if (envar)
-    birnet_msg_allow (envar);
+    sfi_msg_allow (envar);
   envar = getenv ("BST_NO_DEBUG");
   if (envar)
-    birnet_msg_deny (envar);
+    sfi_msg_deny (envar);
   envar = getenv ("BEAST_DEBUG");
   if (envar)
-    birnet_msg_allow (envar);
+    sfi_msg_allow (envar);
   envar = getenv ("BEAST_NO_DEBUG");
   if (envar)
-    birnet_msg_deny (envar);
+    sfi_msg_deny (envar);
 
   gboolean initialize_bse_and_exit = FALSE;
   for (i = 1; i < argc; i++)
@@ -521,9 +520,9 @@ bst_early_parse_args (int    *argc_p,
 	  guint j;
 	  g_print ("BEAST debug keys: all");
 	  for (j = 0; mids[j].ident; j++)
-            if (mids[j].type >= BIRNET_MSG_DEBUG && mids[j].label)
+            if (mids[j].type >= SFI_MSG_DEBUG && mids[j].label && mids[j].label[0])
               g_print (", %s (%s)", mids[j].ident, mids[j].label);
-            else if (mids[j].type >= BIRNET_MSG_DEBUG)
+            else if (mids[j].type >= SFI_MSG_DEBUG)
               g_print (", %s", mids[j].ident);
 	  g_print ("\n");
 	  exit (0);
@@ -535,25 +534,25 @@ bst_early_parse_args (int    *argc_p,
 	  gchar *equal = argv[i] + 7;
 	  
 	  if (*equal == '=')
-            birnet_msg_allow (equal + 1);
+            sfi_msg_allow (equal + 1);
 	  else if (i + 1 < argc)
 	    {
 	      argv[i++] = NULL;
-	      birnet_msg_allow (argv[i]);
+	      sfi_msg_allow (argv[i]);
 	    }
 	  argv[i] = NULL;
 	}
       else if (strcmp ("--no-debug", argv[i]) == 0 ||
-	       strncmp ("--no-debug=", argv[i], 8) == 0)
+	       strncmp ("--no-debug=", argv[i], 11) == 0)
 	{
-	  gchar *equal = argv[i] + 7;
+	  gchar *equal = argv[i] + 10;
 	  
 	  if (*equal == '=')
-            birnet_msg_deny (equal + 1);
+            sfi_msg_deny (equal + 1);
 	  else if (i + 1 < argc)
 	    {
 	      argv[i++] = NULL;
-	      birnet_msg_deny (argv[i]);
+	      sfi_msg_deny (argv[i]);
 	    }
 	  argv[i] = NULL;
 	}
@@ -708,7 +707,9 @@ bst_exit_print_version (void)
   g_print ("GLib %u.%u.%u", glib_major_version, glib_minor_version, glib_micro_version);
   g_print (", SFI %u.%u.%u", bse_major_version, bse_minor_version, bse_micro_version);
   g_print (", BSE %u.%u.%u", bse_major_version, bse_minor_version, bse_micro_version);
-  g_print (", Ogg/Vorbis");
+  c = bse_server_get_vorbis_version (BSE_SERVER);
+  if (c)
+    g_print (", %s", c);
   c = bse_server_get_mp3_version (BSE_SERVER);
   if (c)
     g_print (", %s", c);
@@ -720,8 +721,8 @@ bst_exit_print_version (void)
   g_print ("\n");
   g_print ("Compiled for %s %s SSE plugins.\n", BST_ARCH_NAME, BSE_WITH_SSE_FLAGS ? "with" : "without");
   g_print ("Intrinsic code selected according to runtime CPU detection:\n");
-  const BirnetCPUInfo *cpu_info = birnet_cpu_info();
-  gchar *cpu_blurb = birnet_cpu_info_string (cpu_info);
+  const SfiCPUInfo cpu_info = sfi_cpu_info();
+  gchar *cpu_blurb = sfi_cpu_info_string (&cpu_info);
   g_print ("%s", cpu_blurb);
   g_free (cpu_blurb);
   g_print ("\n");
@@ -741,9 +742,9 @@ bst_exit_print_version (void)
   g_print ("\n");
   g_print ("BEAST comes with ABSOLUTELY NO WARRANTY.\n");
   g_print ("You may redistribute copies of BEAST under the terms of\n");
-  g_print ("the GNU General Public License which can be found in the\n");
-  g_print ("BEAST source package. Sources, examples and contact\n");
-  g_print ("information are available at http://beast.gtk.org/.\n");
+  g_print ("the GNU Lesser General Public License which can be found in\n");
+  g_print ("the BEAST source package. Sources, examples and contact\n");
+  g_print ("information are available at http://beast.testbit.eu/.\n");
   g_free (freeme);
   exit (0);
 }
@@ -824,22 +825,27 @@ beast_show_about_box (void)
     /* general code and fixes */
     "Alper Ersoy",
     "Ben Collver",
+    "Hanno Behrens",
+    "Jonh Wendell",
     "Nedko Arnaudov",
     "Rasmus Kaj",
     "Sam Hocevar",
     "Stefan Westerfeld",
     "Sven Herzberg",
     "Tim Janik",
-    /* plugins */
+    /* plugins & instruments */
     "\xd0\x90\xd1\x80\xd1\x82\xd0\xb5\xd0\xbc \xd0\x9f\xd0\xbe\xd0\xbf\xd0\xbe\xd0\xb2", /* "Artem Popov", */
     "David A. Bartold",
     //"Tim Janik",
     //"Stefan Westerfeld",
+    "William DeVore",
+    "Krzysztof Foltman",
     /* translations */
     "Adam Weinberger",
     "Alexandre Prokoudine",
     "Amanpreet Singh Alam",
     //"Artem Popov",
+    "Bruno Brouard",
     "Christian Neumair",
     "Christian Rose",
     "Christophe Merlet",
@@ -858,23 +864,30 @@ beast_show_about_box (void)
     // "I\xc3\261aki Larra\xc3\261aga Murgotio",
     "Ismael Andres Rubio Rojas",
     "Jens Seidel",
+    "Joe Hansen",
     "Jorge Gonzalez",
+    "Kjartan Maraas",
     "Kees van den Broek",
     "Kostas Papadimas",
     "Laurent Dhima",
+    "Leonardo Ferreira Fontenelle",
+    "Mario Blättermann",
+    "Maxim V. Dziumanenko",
     "Metin Amiroff",
     "Miloslav Trmac",
     "Moritz Mekelburger",
     "Pawan Chitrakar",
-    "Petrecca Michele",
+    "Michele Petrecca",
     "Raphael Higino",
     "Robert Sedak",
     "Satoru SATOH",
     "Steve Murphy",
     "Tino Meinen",
+    "Veeven",
     "Vincent van Adrighem",
     "Xavier Conde Rueda",
     "Yelitza Louze",
+    "Yannig Marchegay",
     NULL
   };
   if (!GTK_WIDGET_VISIBLE (beast_splash))
