@@ -21,6 +21,15 @@
 #define BIRNET_BINARY_AGE		(0)
 #define BIRNET_INTERFACE_AGE		(0)
 
+/* log domain */
+#ifndef BIRNET_LOG_DOMAIN
+#ifdef  G_LOG_DOMAIN
+#define BIRNET_LOG_DOMAIN  G_LOG_DOMAIN
+#else
+#define BIRNET_LOG_DOMAIN  ((const char*) 0)
+#endif
+#endif
+
 /* version checks */
 #define BIRNET_CHECK_VERSION(major,minor,micro)	\
   (BIRNET_MAJOR_VERSION > (major) || \
@@ -29,11 +38,26 @@
     BIRNET_MICRO_VERSION >= (micro)))
 
 /* configure results */
+#define BIRNET_OS_UNIX		(1) /* one of: WIN32 UNIX */
+#define BIRNET_SIZEOF_POINTER		(8)
+#define BIRNET_SIZEOF_LONG		(8)
 #define BIRNET_SIZEOF_SYS_TYPESH_UINT	(4)
-#define BIRNET_SIZEOF_PTH_MUTEX_T	(24)
+#define BIRNET_SIZEOF_PTH_MUTEX_T	(40)
 #define BIRNET_SIZEOF_PTH_COND_T	(48)
 #define BIRNET_HAVE_MUTEXATTR_SETTYPE	(1 && \
                                         BIRNET_SIZEOF_PTH_MUTEX_T && \
                                         BIRNET_SIZEOF_PTH_COND_T)
+#define BIRNET_MEMORY_BARRIER_NEEDED   (1)
+
+#define BIRNET_SYSVAL_POLLIN 		(1)
+#define BIRNET_SYSVAL_POLLPRI		(2)
+#define BIRNET_SYSVAL_POLLOUT		(4)
+#define BIRNET_SYSVAL_POLLRDNORM	(64)
+#define BIRNET_SYSVAL_POLLRDBAND 	(128)
+#define BIRNET_SYSVAL_POLLWRNORM   	(256)
+#define BIRNET_SYSVAL_POLLWRBAND	(512)
+#define BIRNET_SYSVAL_POLLERR		(8)
+#define BIRNET_SYSVAL_POLLHUP		(16)
+#define BIRNET_SYSVAL_POLLNVAL		(32)
 
 /* Generated data ends here */
