@@ -4,24 +4,70 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
-// #define TEST_VERBOSE
+//#define TEST_VERBOSE
 #include <birnet/birnettests.h>
+#include <stdlib.h>
 
 namespace {
 using namespace Birnet;
 
+/* --- utilities --- */
+BirnetThread*
+birnet_thread_run (const gchar     *name,
+                   BirnetThreadFunc func,
+                   gpointer         user_data)
+{
+  g_return_val_if_fail (name && name[0], NULL);
+
+  BirnetThread *thread = ThreadTable.thread_new (name);
+  ThreadTable.thread_ref_sink (thread);
+  if (ThreadTable.thread_start (thread, func, user_data))
+    return thread;
+  else
+    {
+      ThreadTable.thread_unref (thread);
+      return NULL;
+    }
+}
+
+#define birnet_mutex_init(mtx)        (ThreadTable.mutex_init (mtx))
+#define birnet_mutex_lock(mtx)        (ThreadTable.mutex_lock (mtx))
+#define birnet_mutex_trylock(mtx)     (0 == ThreadTable.mutex_trylock (mtx))
+#define birnet_mutex_unlock(mtx)      (ThreadTable.mutex_unlock (mtx))
+#define birnet_mutex_destroy(mtx)     (ThreadTable.mutex_destroy (mtx))
+#define birnet_rec_mutex_init(mtx)    (ThreadTable.rec_mutex_init (mtx))
+#define birnet_rec_mutex_lock(mtx)    (ThreadTable.rec_mutex_lock (mtx))
+#define birnet_rec_mutex_trylock(mtx) (0 == ThreadTable.rec_mutex_trylock (mtx))
+#define birnet_rec_mutex_unlock(mtx)  (ThreadTable.rec_mutex_unlock (mtx))
+#define birnet_rec_mutex_destroy(mtx) (ThreadTable.rec_mutex_destroy (mtx))
+
+#define BIRNET_MUTEX_DECLARE_INITIALIZED(mutexname)                             \
+  BirnetMutex mutexname = { 0 };                                                \
+  static void BIRNET_CONSTRUCTOR                                                \
+  BIRNET_CPP_PASTE4 (__birnet_mutex__autoinit, __LINE__, __, mutexname) (void)  \
+  { ThreadTable.mutex_chain4init (&mutexname); }
+
+#define BIRNET_REC_MUTEX_DECLARE_INITIALIZED(recmtx)                            \
+  BirnetRecMutex recmtx = { { 0 } };                                            \
+  static void BIRNET_CONSTRUCTOR                                                \
+  BIRNET_CPP_PASTE4 (__birnet_rec_mutex__autoinit, __LINE__, __, recmtx) (void) \
+  { ThreadTable.rec_mutex_chain4init (&recmtx); }
+
+#define BIRNET_COND_DECLARE_INITIALIZED(condname)                               \
+  BirnetCond condname = { 0 };                                                  \
+  static void BIRNET_CONSTRUCTOR                                                \
+  BIRNET_CPP_PASTE4 (__birnet_cond__autoinit, __LINE__, __, condname) (void)    \
+  { ThreadTable.cond_chain4init (&condname); }
 
 /* --- atomicity tests --- */
 static volatile guint atomic_count = 0;
@@ -33,12 +79,12 @@ atomic_up_thread (gpointer data)
 {
   volatile int *ip = (int*) data;
   for (guint i = 0; i < 25; i++)
-    birnet_atomic_int_add (ip, +3);
+    ThreadTable.atomic_int_add (ip, +3);
   birnet_mutex_lock (&atomic_mutex);
   atomic_count -= 1;
-  birnet_cond_signal (&atomic_cond);
+  ThreadTable.cond_signal (&atomic_cond);
   birnet_mutex_unlock (&atomic_mutex);
-  TASSERT (strcmp (birnet_thread_get_name (birnet_thread_self()), "AtomicTest") == 0);
+  TASSERT (strcmp (ThreadTable.thread_name (ThreadTable.thread_self()), "AtomicTest") == 0);
 }
 
 static void
@@ -46,12 +92,12 @@ atomic_down_thread (gpointer data)
 {
   volatile int *ip = (int*) data;
   for (guint i = 0; i < 25; i++)
-    birnet_atomic_int_add (ip, -4);
+    ThreadTable.atomic_int_add (ip, -4);
   birnet_mutex_lock (&atomic_mutex);
   atomic_count -= 1;
-  birnet_cond_signal (&atomic_cond);
+  ThreadTable.cond_signal (&atomic_cond);
   birnet_mutex_unlock (&atomic_mutex);
-  TASSERT (strcmp (birnet_thread_get_name (birnet_thread_self()), "AtomicTest") == 0);
+  TASSERT (strcmp (ThreadTable.thread_name (ThreadTable.thread_self()), "AtomicTest") == 0);
 }
 
 static void
@@ -62,7 +108,7 @@ test_atomic (void)
   BirnetThread *threads[count];
   volatile int atomic_counter = 0;
   birnet_mutex_init (&atomic_mutex);
-  birnet_cond_init (&atomic_cond);
+  ThreadTable.cond_init (&atomic_cond);
   atomic_count = count;
   for (int i = 0; i < count; i++)
     {
@@ -73,13 +119,13 @@ test_atomic (void)
   while (atomic_count > 0)
     {
       TACK();
-      birnet_cond_wait (&atomic_cond, &atomic_mutex);
+      ThreadTable.cond_wait (&atomic_cond, &atomic_mutex);
     }
   birnet_mutex_unlock (&atomic_mutex);
   int result = count / 2 * 25 * +3 + count / 2 * 25 * -4;
   // g_printerr ("{ %d ?= %d }", atomic_counter, result);
   for (int i = 0; i < count; i++)
-    birnet_thread_unref (threads[i]);
+    ThreadTable.thread_unref (threads[i]);
   TASSERT (atomic_counter == result);
   TDONE ();
 }
@@ -89,13 +135,15 @@ static void
 plus1_thread (gpointer data)
 {
   guint *tdata = (guint*) data;
-  birnet_thread_sleep (-1);
+  ThreadTable.thread_sleep (-1);
   *tdata += 1;
-  while (!birnet_thread_aborted ())
-    birnet_thread_sleep (-1);
+  while (!ThreadTable.thread_aborted ())
+    ThreadTable.thread_sleep (-1);
 }
 
 static BIRNET_MUTEX_DECLARE_INITIALIZED (static_mutex);
+static BIRNET_REC_MUTEX_DECLARE_INITIALIZED (static_rec_mutex);
+static BIRNET_COND_DECLARE_INITIALIZED (static_cond);
 
 static void
 test_threads (void)
@@ -120,6 +168,21 @@ test_threads (void)
   locked = birnet_mutex_trylock (&static_mutex);
   TASSERT (locked);
   birnet_mutex_unlock (&static_mutex);
+  /* not initializing static_rec_mutex */
+  locked = birnet_rec_mutex_trylock (&static_rec_mutex);
+  TASSERT (locked);
+  birnet_rec_mutex_lock (&static_rec_mutex);
+  locked = birnet_rec_mutex_trylock (&static_rec_mutex);
+  TASSERT (locked);
+  birnet_rec_mutex_unlock (&static_rec_mutex);
+  birnet_rec_mutex_unlock (&static_rec_mutex);
+  birnet_rec_mutex_unlock (&static_rec_mutex);
+  locked = birnet_rec_mutex_trylock (&static_rec_mutex);
+  TASSERT (locked);
+  birnet_rec_mutex_unlock (&static_rec_mutex);
+  /* not initializing static_cond */
+  ThreadTable.cond_signal (&static_cond);
+  ThreadTable.cond_broadcast (&static_cond);
   /* test C++ mutex */
   static Mutex mutex;
   static RecMutex rmutex;
@@ -139,21 +202,21 @@ test_threads (void)
   TASSERT (thread_data1 == 0);
   TASSERT (thread_data2 == 0);
   TASSERT (thread_data3 == 0);
-  TASSERT (birnet_thread_get_running (thread1) == TRUE);
-  TASSERT (birnet_thread_get_running (thread2) == TRUE);
-  TASSERT (birnet_thread_get_running (thread3) == TRUE);
-  birnet_thread_wakeup (thread1);
-  birnet_thread_wakeup (thread2);
-  birnet_thread_wakeup (thread3);
-  birnet_thread_abort (thread1);
-  birnet_thread_abort (thread2);
-  birnet_thread_abort (thread3);
+  TASSERT (ThreadTable.thread_get_running (thread1) == TRUE);
+  TASSERT (ThreadTable.thread_get_running (thread2) == TRUE);
+  TASSERT (ThreadTable.thread_get_running (thread3) == TRUE);
+  ThreadTable.thread_wakeup (thread1);
+  ThreadTable.thread_wakeup (thread2);
+  ThreadTable.thread_wakeup (thread3);
+  ThreadTable.thread_abort (thread1);
+  ThreadTable.thread_abort (thread2);
+  ThreadTable.thread_abort (thread3);
   TASSERT (thread_data1 > 0);
   TASSERT (thread_data2 > 0);
   TASSERT (thread_data3 > 0);
-  birnet_thread_unref (thread1);
-  birnet_thread_unref (thread2);
-  birnet_thread_unref (thread3);
+  ThreadTable.thread_unref (thread1);
+  ThreadTable.thread_unref (thread2);
+  ThreadTable.thread_unref (thread3);
   TDONE ();
 }
 
@@ -172,7 +235,7 @@ struct ThreadA : public virtual Birnet::Thread {
     TASSERT (this->name() == "ThreadA");
     TASSERT (this->name() == Thread::Self::name());
     for (int j = 0; j < 17905; j++)
-      birnet_atomic_int_add (counter, value);
+      ThreadTable.atomic_int_add (counter, value);
   }
 };
 
@@ -433,8 +496,9 @@ test_auto_locker_cxx()
 class HeapLocker {
   // like PtrAutoLocker but allocates on the heap
   struct Lockable {
-    virtual void lock() = 0;
-    virtual void unlock() = 0;
+    virtual void lock     () = 0;
+    virtual void unlock   () = 0;
+    virtual     ~Lockable () {}
   };
   template<class L>
   struct Wrapper : public virtual Lockable {
@@ -520,6 +584,7 @@ class GenericAutoLocker {
   struct Locker {
     virtual void lock   () const = 0;
     virtual void unlock () const = 0;
+    virtual     ~Locker () {}
   };
   template<class Lockable>
   struct LockerImpl : public Locker {
@@ -565,6 +630,7 @@ class PtrAutoLocker {
   struct Locker {
     virtual void lock   () = 0;
     virtual void unlock () = 0;
+    virtual     ~Locker () {}
   };
   template<class Lockable>
   struct LockerImpl : public Locker {
@@ -721,12 +787,12 @@ bench_auto_locker_cxx()
   TACK();
   /* done, report */
   TDONE();
-  g_print ("Manual-Locker:      %7.3f nsecs\n", xmin / xdups / RUNS * 1000. * 1000. * 1000.);
-  g_print ("Direct-AutoLocker:  %7.3f nsecs\n", smin / sdups / RUNS * 1000. * 1000. * 1000.);
-  g_print ("Generic-AutoLocker: %7.3f nsecs\n", gmin / gdups / RUNS * 1000. * 1000. * 1000.);
-  g_print ("Birnet-AutoLocker:  %7.3f nsecs\n", bmin / bdups / RUNS * 1000. * 1000. * 1000.);
-  g_print ("Pointer-AutoLocker: %7.3f nsecs\n", pmin / pdups / RUNS * 1000. * 1000. * 1000.);
-  g_print ("Heap-AutoLocker:    %7.3f nsecs\n", tmin / tdups / RUNS * 1000. * 1000. * 1000.);
+  treport_minimized ("Manual-Locker",      xmin / xdups / RUNS * 1000. * 1000. * 1000., TUNIT_NSEC);
+  treport_minimized ("Direct-AutoLocker",  smin / sdups / RUNS * 1000. * 1000. * 1000., TUNIT_NSEC);
+  treport_minimized ("Generic-AutoLocker", gmin / gdups / RUNS * 1000. * 1000. * 1000., TUNIT_NSEC);
+  treport_minimized ("Birnet-AutoLocker",  bmin / bdups / RUNS * 1000. * 1000. * 1000., TUNIT_NSEC);
+  treport_minimized ("Pointer-AutoLocker", pmin / pdups / RUNS * 1000. * 1000. * 1000., TUNIT_NSEC);
+  treport_minimized ("Heap-AutoLocker",    tmin / tdups / RUNS * 1000. * 1000. * 1000., TUNIT_NSEC);
 }
 
 /* --- C++ atomicity tests --- */
@@ -770,7 +836,7 @@ test_thread_atomic_cxx (void)
   r = Atomic::int_get (&ai);
   TASSERT (r == 0);
   /* pointer functions */
-  volatile void *ap, *p;
+  void * volatile ap, * volatile p;
   Atomic::ptr_set (&ap, (void*) 119);
   TASSERT (ap == (void*) 119);
   p = Atomic::ptr_get (&ap);
@@ -786,6 +852,291 @@ test_thread_atomic_cxx (void)
   TDONE ();
 }
 
+/* --- thread_yield --- */
+static inline void
+handle_contention ()
+{
+  /* we're waiting for our contention counterpart if we got here:
+   * - sched_yield(3posix) will immediately give up the CPU and let another
+   *   task run. but if the contention counterpart is running on another
+   *   CPU this will lead to scheduler trashing on our CPU. and if other
+   *   bacground tasks are running, they could get all our CPU time,
+   *   because sched_yield() effectively discards the current time slice.
+   * - busy spinning is useful if the contention counterpart runs on a
+   *   different CPU, as long as the loop doesn't involve syncronization
+   *   primitives which cause IO bus trashing ("lock" prefix in x86 asm).
+   * - usleep(3posix) is a way to give up the CPU without discarding our
+   *   time slices and avoids scheduler or bus trashing. allthough it is
+   *   not the perfect or optimum syncronization/timing primitive, it
+   *   avoids most ill effects and still allows for a sufficient number
+   *   of task switches.
+   */
+  usleep (500); // 1usec is the minimum value to cause an effect
+}
+
+/* --- ring buffer --- */
+typedef Atomic::RingBuffer<int> IntRingBuffer;
+class IntSequence {
+  uint32 accu;
+public:
+  explicit      IntSequence() : accu (123456789) {}
+  inline int32  gen_int    () { accu = 1664525 * accu + 1013904223; return accu; }
+};
+#define CONTENTION_PRINTF       if(1);else g_printerr
+struct RingBufferWriter : public virtual Birnet::Thread, IntSequence {
+  IntRingBuffer *ring;
+  uint           ring_buffer_test_length;
+  RingBufferWriter (IntRingBuffer *rb,
+                    uint           rbtl) :
+    Thread ("RingBufferWriter"),
+    ring (rb), ring_buffer_test_length (rbtl)
+  {}
+  virtual void
+  run ()
+  {
+    TPRINT ("%s start.", Thread::Self::name().c_str());
+    for (uint l = 0; l < ring_buffer_test_length;)
+      {
+        uint k, n = g_random_int() % MIN (ring_buffer_test_length - l + 1, 65536 * 2);
+        int buffer[n], *b = buffer;
+        for (uint i = 0; i < n; i++)
+          b[i] = gen_int();
+        uint j = n;
+        while (j)
+          {
+            k = ring->write (j, b);
+            TCHECK (k <= j);
+            j -= k;
+            b += k;
+            if (!k)     // waiting for reader thread
+              handle_contention();
+            CONTENTION_PRINTF (k ? "*" : "/");
+          }
+        if (l / 499999 != (l + n) / 499999)
+          TICK();
+        l += n;
+      }
+    TPRINT ("%s done.", Thread::Self::name().c_str());
+  }
+};
+struct RingBufferReader : public virtual Birnet::Thread, IntSequence {
+  IntRingBuffer *ring;
+  uint           ring_buffer_test_length;
+  RingBufferReader (IntRingBuffer *rb,
+                    uint           rbtl) :
+    Thread ("RingBufferReader"),
+    ring (rb), ring_buffer_test_length (rbtl)
+  {}
+  virtual void
+  run ()
+  {
+    TPRINT ("%s start.", Thread::Self::name().c_str());
+    for (uint l = 0; l < ring_buffer_test_length;)
+      {
+        uint k, n = ring->n_readable();
+        n = lrand48() % MIN (n + 1, 65536 * 2);
+        int buffer[n], *b = buffer;
+        if (rand() & 1)
+          {
+            k = ring->read (n, b, false);
+            TCHECK (n == k);
+            if (k)
+              CONTENTION_PRINTF ("+");
+          }
+        else
+          {
+            k = ring->read (n, b, true);
+            TCHECK (k <= n);
+            if (!k)         // waiting for writer thread
+              handle_contention();
+            CONTENTION_PRINTF (k ? "+" : "\\");
+          }
+        for (uint i = 0; i < k; i++)
+          TCHECK (b[i] == gen_int());
+        if (l / 499999 != (l + k) / 499999)
+          TACK();
+        l += k;
+      }
+    TPRINT ("%s done.", Thread::Self::name().c_str());
+  }
+};
+
+static void
+test_ring_buffer ()
+{
+  static const gchar *testtext = "Ring Buffer test Text (47\xff)";
+  uint n, ttl = strlen (testtext);
+  TSTART ("RingBuffer");
+  Atomic::RingBuffer<char> rb1 (ttl);
+  TASSERT (rb1.n_writable() == ttl);
+  n = rb1.write (ttl, testtext);
+  TASSERT (n == ttl);
+  TASSERT (rb1.n_writable() == 0);
+  TASSERT (rb1.n_readable() == ttl);
+  char buffer[8192];
+  n = rb1.read (8192, buffer);
+  TASSERT (n == ttl);
+  TASSERT (rb1.n_readable() == 0);
+  TASSERT (rb1.n_writable() == ttl);
+  TASSERT (strncmp (buffer, testtext, n) == 0);
+  TDONE();
+
+  /* check lower end ring buffer sizes (high contention test) */
+  for (uint step = 1; step < 8; step++)
+    {
+      uint ring_buffer_test_length = 17 * step + (rand() % 19);
+      TSTART ("AsyncRingBuffer-%d-%d", step, ring_buffer_test_length);
+      IntRingBuffer irb (step);
+      RingBufferReader *rbr = new RingBufferReader (&irb, ring_buffer_test_length);
+      ref_sink (rbr);
+      RingBufferWriter *rbw = new RingBufferWriter (&irb, ring_buffer_test_length);
+      ref_sink (rbw);
+      TASSERT (rbr && rbw);
+      rbr->start();
+      rbw->start();
+      rbw->wait_for_exit();
+      rbr->wait_for_exit();
+      TASSERT (rbr && rbw);
+      unref (rbr);
+      unref (rbw);
+      TDONE();
+    }
+
+  /* check big ring buffer sizes */
+  if (true)
+    {
+      TSTART ("AsyncRingBuffer-big");
+      uint ring_buffer_test_length = 999999 * (init_settings().test_quick ? 1 : 20);
+      IntRingBuffer irb (16384 + (lrand48() % 8192));
+      RingBufferReader *rbr = new RingBufferReader (&irb, ring_buffer_test_length);
+      ref_sink (rbr);
+      RingBufferWriter *rbw = new RingBufferWriter (&irb, ring_buffer_test_length);
+      ref_sink (rbw);
+      TASSERT (rbr && rbw);
+      rbr->start();
+      rbw->start();
+      rbw->wait_for_exit();
+      rbr->wait_for_exit();
+      TASSERT (rbr && rbw);
+      unref (rbr);
+      unref (rbw);
+      TDONE();
+    }
+}
+
+/* --- --- */
+static void
+test_debug_channel ()
+{
+  TSTART ("DebugChannelFileAsync (countdown)");
+  DebugChannel *dbg = DebugChannel::new_from_file_async ("/dev/stderr");
+  ref_sink (dbg);
+  TASSERT (dbg);
+  dbg->printf ("9");
+  usleep (100 * 1000);
+  dbg->printf ("8");
+  usleep (110 * 1000);
+  dbg->printf ("7");
+  usleep (120 * 1000);
+  dbg->printf ("6");
+  usleep (130 * 1000);
+  dbg->printf ("5");
+  usleep (140 * 1000);
+  dbg->printf ("4");
+  usleep (150 * 1000);
+  dbg->printf ("3");
+  usleep (160 * 1000);
+  dbg->printf ("2");
+  usleep (170 * 1000);
+  dbg->printf ("1");
+  usleep (180 * 1000);
+  dbg->printf ("0");
+  usleep (190 * 1000);
+  unref (dbg);
+  TICK();
+  TDONE();
+}
+
+/* --- late deletable destruction --- */
+static bool deletable_destructor = false;
+struct MyDeletable : public virtual Deletable {
+  virtual
+  ~MyDeletable()
+  {
+    deletable_destructor = true;
+  }
+  void
+  force_deletion_hooks()
+  {
+    invoke_deletion_hooks();
+  }
+};
+struct MyDeletableHook : public Deletable::DeletionHook {
+  Deletable *deletable;
+  explicit     MyDeletableHook () :
+    deletable (NULL)
+  {}
+  virtual void
+  monitoring_deletable (Deletable &deletable_obj)
+  {
+    TASSERT (deletable == NULL);
+    deletable = &deletable_obj;
+  }
+  virtual void
+  dismiss_deletable ()
+  {
+    if (deletable)
+      deletable = NULL;
+  }
+  virtual
+  ~MyDeletableHook ()
+  {
+    // g_printerr ("~MyDeletableHook(): deletable=%p\n", deletable);
+    if (deletable)
+      deletable_remove_hook (deletable);
+    deletable = NULL;
+  }
+};
+
+static MyDeletable early_deletable __attribute__ ((init_priority (101)));
+static MyDeletable late_deletable __attribute__ ((init_priority (65535)));
+
+static void
+test_deletable_destruction ()
+{
+  TSTART ("Deletable destruction");
+  {
+    MyDeletable test_deletable;
+    TICK();
+    MyDeletableHook dhook1;
+    // g_printerr ("TestHook=%p\n", (Deletable::DeletionHook*) &dhook1);
+    dhook1.deletable_add_hook (&test_deletable);
+    TICK();
+    dhook1.deletable_remove_hook (&test_deletable);
+    dhook1.dismiss_deletable();
+    TICK();
+    MyDeletableHook dhook2;
+    dhook2.deletable_add_hook (&test_deletable);
+    test_deletable.force_deletion_hooks ();
+    TICK();
+    MyDeletableHook dhook3;
+    dhook3.deletable_add_hook (&test_deletable);
+    TICK();
+    /* automatic deletion hook invocation */
+    /* FIXME: deletable destructor is called first and doesn't auto-remove
+     * - if deletion hooks were ring-linked, we could at least catch this case in ~DeletionHook
+     */
+  }
+  MyDeletable *deletable2 = new MyDeletable;
+  TASSERT (deletable2 != NULL);
+  deletable_destructor = false;
+  delete deletable2;
+  TASSERT (deletable_destructor == true);
+  TDONE();
+  /* early_deletable and late_deletable are only tested at program end */
+}
+
+/* --- Mutextes before g_thread_init() --- */
 static void
 test_before_thread_init()
 {
@@ -800,10 +1151,21 @@ test_before_thread_init()
 
 } // Anon
 
+static guint constructur_attribute_test = 0;
+
+static void BIRNET_CONSTRUCTOR
+constructur_attribute_test_initializer (void)
+{
+  constructur_attribute_test = 0x1237ABBA;
+}
+
 int
 main (int   argc,
       char *argv[])
 {
+  if (constructur_attribute_test != 305638330)
+    g_error ("%s: static constructors have not been called before main", G_STRFUNC);
+
   test_before_thread_init();
 
   birnet_init_test (&argc, &argv);
@@ -813,7 +1175,11 @@ main (int   argc,
   test_thread_cxx();
   test_thread_atomic_cxx();
   test_auto_locker_cxx();
-  bench_auto_locker_cxx();
+  test_deletable_destruction();
+  test_ring_buffer(); 
+  test_debug_channel(); 
+  if (init_settings().test_perf)
+    bench_auto_locker_cxx();
   
   return 0;
 }
