@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2002-2006 Tim Janik
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsemain.h"
 #include "bsecategories.h"
@@ -559,23 +558,23 @@ main (gint   argc,
   gboolean gen_objects = FALSE;
   char pluginbool[2] = "0";
   char scriptbool[2] = "0";
-  BirnetInitValue config[] = {
+  SfiInitValue config[] = {
     { "load-core-plugins", pluginbool },
     { "load-core-scripts", scriptbool },
     { NULL },
   };
 
   g_thread_init (NULL);
-  birnet_init (&argc, &argv, "BseAutoDoc");
+  sfi_init (&argc, &argv, "BseAutoDoc", NULL);
   boxed_type_tag = g_quark_from_static_string ("bse-auto-doc-boxed-type-tag");
   
   guint i;
   for (i = 1; i < argc; i++)
     {
       if (strcmp ("-p", argv[i]) == 0)
-        pluginbool[1] = '1';
+        pluginbool[0] = '1';
       else if (strcmp ("-s", argv[i]) == 0)
-        scriptbool[1] = '1';
+        scriptbool[0] = '1';
       else if (strcmp ("--bse-rcfile", argv[i]) == 0 && i + 1 < argc)
         {
           /* ignore, BSE handles this */
