@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2002 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsebiquadfilter.h"
 
@@ -21,7 +20,7 @@
 #include <bse/bseengine.h>
 #include <bse/bsemathsignal.h>
 
-static BIRNET_MSG_TYPE_DEFINE (debug_biquadfilter, "biquadfilter", BIRNET_MSG_DEBUG, NULL);
+static SFI_MSG_TYPE_DEFINE (debug_biquadfilter, "biquadfilter", SFI_MSG_DEBUG, NULL);
 #define	DEBUG(...)      sfi_debug (debug_biquadfilter, __VA_ARGS__)
 #define FREQ_DELTA      0.1
 
@@ -131,7 +130,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, _("Center Frequency"),
 			      PROP_FREQ,
-			      sfi_pspec_log_scale ("freq", _("Cutoff [Hz]"), NULL,
+			      sfi_pspec_log_scale ("freq", _("Cutoff [Hz]"), _("Filter cutoff frequency in Hertz"),
 						   BSE_KAMMER_FREQUENCY * 2,
 						   BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY - FREQ_DELTA,
 						   5.0,
@@ -139,8 +138,9 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						   SFI_PARAM_STANDARD ":dial"));
   bse_object_class_add_param (object_class, _("Center Frequency"),
 			      PROP_NOTE,
-			      sfi_pspec_note ("note", _("Note"), NULL,
-					      bse_note_from_freq (BSE_KAMMER_FREQUENCY * 2),
+			      sfi_pspec_note ("note", _("Note"), _("Filter cutoff frequency as note, "
+                                                                   "converted to Hertz according to the current musical tuning"),
+					      bse_note_from_freq (BSE_MUSICAL_TUNING_12_TET, BSE_KAMMER_FREQUENCY * 2),
 					      BSE_MIN_NOTE, BSE_MAX_NOTE,
 					      FALSE,
 					      SFI_PARAM_GUI));
@@ -232,7 +232,7 @@ bse_biquad_filter_set_property (GObject	     *object,
       g_object_notify (self, "note");
       break;
     case PROP_NOTE:
-      self->freq = bse_note_to_freq (sfi_value_get_note (value));
+      self->freq = bse_note_to_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), sfi_value_get_note (value));
       bse_biquad_filter_update_modules (self);
       g_object_notify (self, "freq");
       break;
@@ -284,7 +284,7 @@ bse_biquad_filter_get_property (GObject	   *object,
       sfi_value_set_real (value, self->freq);
       break;
     case PROP_NOTE:
-      sfi_value_set_note (value, bse_note_from_freq (self->freq));
+      sfi_value_set_note (value, bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), self->freq));
       break;
     case PROP_FM_PERC:
       sfi_value_set_real (value, self->fm_strength * 100.0);
