@@ -1,20 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2004 Tim Janik
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsebus.h"
 #include "bsecategories.h"
@@ -619,8 +617,10 @@ bse_bus_ensure_summation (BseBus *self)
         self->summation = bse_song_create_summation (BSE_SONG (item->parent));
       if (self->summation)
         {
-          bse_source_must_set_input (BSE_SOURCE (self), 0, self->summation, 0);
-          bse_source_must_set_input (BSE_SOURCE (self), 1, self->summation, 1);
+          bse_source_must_set_input (BSE_SOURCE (self), BSE_BUS_OCHANNEL_LEFT,
+                                     self->summation, bse_source_find_ochannel (self->summation, "audio-out1"));
+          bse_source_must_set_input (BSE_SOURCE (self), BSE_BUS_OCHANNEL_RIGHT,
+                                     self->summation, bse_source_find_ochannel (self->summation, "audio-out2"));
         }
     }
   return self->summation != NULL;
@@ -806,14 +806,17 @@ bus_restore_private (BseObject  *object,
 }
 
 static void
-bus_restore_finish (BseObject *object)
+bus_restore_finish (BseObject *object,
+                    guint      vmajor,
+                    guint      vminor,
+                    guint      vmicro)
 {
   BseBus *self = BSE_BUS (object);
   /* restore real sync setting */
   g_object_set (self, /* no undo */
                 "sync", self->saved_sync,
                 NULL);
-  BSE_OBJECT_CLASS (bus_parent_class)->restore_finish (object);
+  BSE_OBJECT_CLASS (bus_parent_class)->restore_finish (object, vmajor, vminor, vmicro);
 }
 
 static void
