@@ -1,19 +1,18 @@
 /* BSE Engine - Flow module operation engine
  * Copyright (C) 2001, 2002, 2003, 2004 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bseenginemaster.h"
 #include "bseblockutils.hh"
@@ -29,9 +28,9 @@
 #include <sys/time.h>
 #include <errno.h>
 
-static BIRNET_MSG_TYPE_DEFINE (debug_job, "job", BIRNET_MSG_DEBUG, NULL);
+static SFI_MSG_TYPE_DEFINE (debug_job, "job", SFI_MSG_DEBUG, NULL);
 #define JOB_DEBUG(...)  sfi_debug (debug_job, __VA_ARGS__)
-static BIRNET_MSG_TYPE_DEFINE (debug_tjob, "tjob", BIRNET_MSG_DEBUG, NULL);
+static SFI_MSG_TYPE_DEFINE (debug_tjob, "tjob", SFI_MSG_DEBUG, NULL);
 #define TJOB_DEBUG(...) sfi_debug (debug_tjob, __VA_ARGS__)
 
 #define	NODE_FLAG_RECONNECT(node)  G_STMT_START { /*(node)->needs_reset = TRUE*/; } G_STMT_END
@@ -320,9 +319,9 @@ master_process_job (BseJob *job)
       master_schedule_discard();
       GSL_SPIN_LOCK (job->sync.lock_mutex);
       *job->sync.lock_p = TRUE;
-      birnet_cond_signal (job->sync.lock_cond);
+      sfi_cond_signal (job->sync.lock_cond);
       while (*job->sync.lock_p)
-        birnet_cond_wait (job->sync.lock_cond, job->sync.lock_mutex);
+        sfi_cond_wait (job->sync.lock_cond, job->sync.lock_mutex);
       GSL_SPIN_UNLOCK (job->sync.lock_mutex);
       break;
     case ENGINE_JOB_INTEGRATE:
@@ -741,7 +740,11 @@ master_take_probes (EngineNode   *node,
       tjob->probe.ostreams = ostreams;
       for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
         {
+          /* restore real ostream buffer pointers */
+          ostreams[i].values = node->outputs[i].buffer;
+          /* store real ostream buffer pointers */
           node->outputs[i].buffer = node->module.ostreams[i].values;
+          /* preserve connection flags */
           node->module.ostreams[i].connected = ostreams[i].connected;
         }
     }
@@ -755,7 +758,7 @@ master_take_probes (EngineNode   *node,
           if (input->real_node && input->real_node->module.ostreams[input->real_stream].connected)
             {
               tjob->probe.ostreams[i].connected = true;
-              bse_block_copy_float (n_values, tjob->probe.ostreams[i].values, input->real_node->module.ostreams[input->real_stream].values);
+              bse_block_copy_float (n_values, tjob->probe.ostreams[i].values, input->real_node->outputs[input->real_stream].buffer);
             }
         }
     }
@@ -803,12 +806,14 @@ master_process_locked_node (EngineNode *node,
   const guint64 current_stamp = GSL_TICK_STAMP;
   guint64 next_counter, new_counter, final_counter = current_stamp + n_values;
   guint i, j, diff;
-  
+  bool needs_probe_reset = node->probe_jobs != NULL;
+
   g_return_if_fail (node->integrated && node->sched_tag);
   
   while (node->counter < final_counter)
     {
       /* call reset() and exec flow jobs */
+      /* FIXME: decide whether flow jobs can rely on valid ostream[].values pointers or not */
       next_counter = master_update_node_state (node, node->counter);
       /* figure n_values to process */
       new_counter = MIN (next_counter, final_counter);
@@ -845,9 +850,13 @@ master_process_locked_node (EngineNode *node,
 	    node->module.jstreams[j].values[i] += diff;
 	    ENGINE_NODE_UNLOCK (inode);
 	  }
-      /* update obuffer pointer */
+      /* update obuffer pointer (FIXME: need this before flow job callbacks?) */
       for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
-	node->module.ostreams[i].values = node->outputs[i].buffer + diff;
+        node->module.ostreams[i].values = node->outputs[i].buffer + diff;
+      if (diff && needs_probe_reset)
+        for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
+          bse_block_fill_float (diff, node->outputs[i].buffer, 0.0);
+      needs_probe_reset = false;
       /* process() node */
       if (UNLIKELY (ENGINE_NODE_IS_SUSPENDED (node, node->counter)))
 	{
@@ -1132,16 +1141,16 @@ _engine_master_dispatch (void)
 void
 bse_engine_master_thread (EngineMasterData *mdata)
 {
-  birnet_msg_set_thread_handler (bse_msg_handler);
+  bse_message_setup_thread_handler ();
 
   /* assert pollfd equality, since we're simply casting structures */
-  g_static_assert (sizeof (struct pollfd) == sizeof (GPollFD));
-  g_static_assert (G_STRUCT_OFFSET (GPollFD, fd) == G_STRUCT_OFFSET (struct pollfd, fd));
-  g_static_assert (sizeof (((GPollFD*) 0)->fd) == sizeof (((struct pollfd*) 0)->fd));
-  g_static_assert (G_STRUCT_OFFSET (GPollFD, events) == G_STRUCT_OFFSET (struct pollfd, events));
-  g_static_assert (sizeof (((GPollFD*) 0)->events) == sizeof (((struct pollfd*) 0)->events));
-  g_static_assert (G_STRUCT_OFFSET (GPollFD, revents) == G_STRUCT_OFFSET (struct pollfd, revents));
-  g_static_assert (sizeof (((GPollFD*) 0)->revents) == sizeof (((struct pollfd*) 0)->revents));
+  BIRNET_STATIC_ASSERT (sizeof (struct pollfd) == sizeof (GPollFD));
+  BIRNET_STATIC_ASSERT (G_STRUCT_OFFSET (GPollFD, fd) == G_STRUCT_OFFSET (struct pollfd, fd));
+  BIRNET_STATIC_ASSERT (sizeof (((GPollFD*) 0)->fd) == sizeof (((struct pollfd*) 0)->fd));
+  BIRNET_STATIC_ASSERT (G_STRUCT_OFFSET (GPollFD, events) == G_STRUCT_OFFSET (struct pollfd, events));
+  BIRNET_STATIC_ASSERT (sizeof (((GPollFD*) 0)->events) == sizeof (((struct pollfd*) 0)->events));
+  BIRNET_STATIC_ASSERT (G_STRUCT_OFFSET (GPollFD, revents) == G_STRUCT_OFFSET (struct pollfd, revents));
+  BIRNET_STATIC_ASSERT (sizeof (((GPollFD*) 0)->revents) == sizeof (((struct pollfd*) 0)->revents));
 
   /* add the thread wakeup pipe to master pollfds,
    * so we get woken  up in time.
@@ -1153,7 +1162,7 @@ bse_engine_master_thread (EngineMasterData *mdata)
   
   toyprof_stampinit ();
   
-  while (!birnet_thread_aborted ())        /* also updates accounting information */
+  while (!sfi_thread_aborted ())        /* also updates accounting information */
     {
       BseEngineLoop loop;
       gboolean need_dispatch;
@@ -1186,7 +1195,7 @@ bse_engine_master_thread (EngineMasterData *mdata)
       
       /* wakeup user thread if necessary */
       if (bse_engine_has_garbage ())
-	birnet_thread_wakeup (mdata->user_thread);
+	sfi_thread_wakeup (mdata->user_thread);
     }
 }
 
