@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 
 /* --- gsldatacache.h --- */
@@ -52,7 +52,7 @@ extern GType BSE_TYPE_ID (BseStandardOscWaveType);
 #define BSE_TYPE_MIDI_DECODER_STATE	    (BSE_TYPE_ID (BseMidiDecoderState))
 extern GType BSE_TYPE_ID (BseMidiDecoderState);
 
-/* Generated data ends here */
+
 
 
 /*
@@ -86,7 +86,7 @@ extern GType bse_type_builtin_id_BseItem;
 /* --- bsejanitor.c --- */
 extern GType bse_type_builtin_id_BseJanitor;
 
-/* --- bseladspa.c --- */
+/* --- bseladspa.cc --- */
 extern GType bse_type_builtin_id_BseLadspaPlugin;
 
 /* --- bsemidicontroller.c --- */
@@ -217,6 +217,26 @@ extern GType bse_type_builtin_id_BseMidiInput;
 
 /* enums */
 
+typedef enum {
+  BSE_MUSICAL_TUNING_12_TET = 1,
+  BSE_MUSICAL_TUNING_7_TET = 2,
+  BSE_MUSICAL_TUNING_5_TET = 3,
+  BSE_MUSICAL_TUNING_DIATONIC_SCALE = 4,
+  BSE_MUSICAL_TUNING_INDIAN_SCALE = 5,
+  BSE_MUSICAL_TUNING_PYTHAGOREAN_TUNING = 6,
+  BSE_MUSICAL_TUNING_PENTATONIC_5_LIMIT = 7,
+  BSE_MUSICAL_TUNING_PENTATONIC_BLUES = 8,
+  BSE_MUSICAL_TUNING_PENTATONIC_GOGO = 9,
+  BSE_MUSICAL_TUNING_QUARTER_COMMA_MEANTONE = 10,
+  BSE_MUSICAL_TUNING_SILBERMANN_SORGE = 11,
+  BSE_MUSICAL_TUNING_WERCKMEISTER_3 = 12,
+  BSE_MUSICAL_TUNING_WERCKMEISTER_4 = 13,
+  BSE_MUSICAL_TUNING_WERCKMEISTER_5 = 14,
+  BSE_MUSICAL_TUNING_WERCKMEISTER_6 = 15,
+  BSE_MUSICAL_TUNING_KIRNBERGER_3 = 16,
+  BSE_MUSICAL_TUNING_YOUNG = 17,
+} BseMusicalTuningType;
+
 typedef enum {
   BSE_MIDI_SIGNAL_PROGRAM = 1,
   BSE_MIDI_SIGNAL_PRESSURE = 2,
@@ -579,7 +599,7 @@ typedef enum {
 
 typedef enum {
   BSE_MSG_NONE = 0,
-  BSE_MSG_FATAL = 1,
+  BSE_MSG_ALWAYS = 1,
   BSE_MSG_ERROR = 2,
   BSE_MSG_WARNING = 3,
   BSE_MSG_SCRIPT = 4,
@@ -725,6 +745,7 @@ struct _BsePartControl {
   SfiBool selected;
 };
 struct _BseNoteDescription {
+  BseMusicalTuningType musical_tuning;
   SfiInt note;
   SfiInt octave;
   SfiReal freq;
@@ -1066,6 +1087,7 @@ void bse_thread_info_seq_free (BseThreadInfoSeq* seq);
 
 
 /* enum functions */
+SfiChoiceValues bse_musical_tuning_type_get_values (void);
 SfiChoiceValues bse_midi_signal_type_get_values (void);
 SfiChoiceValues bse_midi_control_type_get_values (void);
 SfiChoiceValues bse_midi_channel_event_type_get_values (void);
@@ -1074,6 +1096,7 @@ SfiChoiceValues bse_thread_state_get_values (void);
 
 
 /* enum type ids */
+extern GType bse__type_id__musical_tuning_type;
 extern GType bse__type_id__midi_signal_type;
 extern GType bse__type_id__midi_control_type;
 extern GType bse__type_id__midi_channel_event_type;
@@ -1119,6 +1142,7 @@ extern GType bse__type_id__thread_info_seq;
 
 
 /* enum type macros */
+#define BSE_TYPE_MUSICAL_TUNING_TYPE		(bse__type_id__musical_tuning_type)
 #define BSE_TYPE_MIDI_SIGNAL_TYPE		(bse__type_id__midi_signal_type)
 #define BSE_TYPE_MIDI_CONTROL_TYPE		(bse__type_id__midi_control_type)
 #define BSE_TYPE_MIDI_CHANNEL_EVENT_TYPE		(bse__type_id__midi_channel_event_type)
