@@ -4,17 +4,15 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bseloader.h"
 
@@ -107,8 +105,8 @@ typedef struct
   Word  n_channels;             /* 1 = Mono, 2 = Stereo */
   DWord sample_freq;
   DWord byte_per_second;
-  Word  byte_per_sample;        /* 1 = 8bit, 2 = 16bit */
-  Word  bit_per_sample;         /* 8, 12 or 16 */
+  Word  byte_per_sample;        /* 1 = 8bit, 2 = 16bit, 3 = 24bit, 4 = 24bit or 32 bit */
+  Word  bit_per_sample;         /* 8, 12, 16, 32 */
 } FmtHeader;
 static BseErrorType
 wav_read_fmt_header (gint       fd,
@@ -165,20 +163,25 @@ wav_read_fmt_header (gint       fd,
       WAV_DEBUG ("invalid sample_freq (%u)", header->sample_freq);
       return BSE_ERROR_FORMAT_UNKNOWN;
     }
-  if (header->byte_per_sample < 1 || header->byte_per_sample > 4 ||
-      (header->bit_per_sample != 8 && header->bit_per_sample != 12 && header->bit_per_sample != 16))
+  if (header->byte_per_sample < 1 * header->n_channels || header->byte_per_sample > 4 * header->n_channels ||
+      (header->bit_per_sample != 8 && header->bit_per_sample != 12 && header->bit_per_sample != 16 &&
+       header->bit_per_sample != 24 && header->bit_per_sample != 32))
     {
       WAV_DEBUG ("invalid byte_per_sample (%u) or bit_per_sample (%u)", header->byte_per_sample, header->bit_per_sample);
       return BSE_ERROR_FORMAT_UNKNOWN;
     }
-  if (header->byte_per_second != header->sample_freq * header->byte_per_sample ||
-      header->byte_per_sample != (header->bit_per_sample + 7) / 8 * header->n_channels)
+  if (header->byte_per_second != header->sample_freq * header->byte_per_sample)
     {
-      WAV_DEBUG ("invalid byte_per_second (%u!=%u) or byte_per_sample (%u!=%u)",
-		 header->byte_per_second, header->sample_freq * header->byte_per_sample,
-		 header->byte_per_sample, (header->bit_per_sample + 7) / 8 * header->n_channels);
+      WAV_DEBUG ("invalid byte_per_second (%u!=%u)", header->byte_per_second, header->sample_freq * header->byte_per_sample);
       return BSE_ERROR_FORMAT_INVALID;
     }
+  if (!(header->byte_per_sample == (header->bit_per_sample + 7) / 8 * header->n_channels ||
+        (header->bit_per_sample == 24 && header->byte_per_sample == 4 * header->n_channels)))
+    {
+      WAV_DEBUG ("invalid byte_per_sample (%u!=%u)", header->byte_per_sample, (header->bit_per_sample + 7) / 8 * header->n_channels);
+      return BSE_ERROR_FORMAT_INVALID;
+    }
+  WAV_DEBUG ("WAVE: freq=%u channels=%u bits=%u bytes=%u", header->sample_freq, header->n_channels, header->bit_per_sample, header->byte_per_sample);
   if (header->length > 16)
     {
       guint n;
@@ -369,8 +372,21 @@ wav_load_wave_dsc (gpointer         data,
     case 8:	format = GSL_WAVE_FORMAT_UNSIGNED_8;	break;
     case 12:	format = GSL_WAVE_FORMAT_SIGNED_12;	break;
     case 16:	format = GSL_WAVE_FORMAT_SIGNED_16;	break;
+    case 32:	format = GSL_WAVE_FORMAT_SIGNED_32;	break;
+    case 24:
+      if (fmt_header.byte_per_sample == 4 * fmt_header.n_channels)
+        {
+          format = GSL_WAVE_FORMAT_SIGNED_24_PAD4;
+          break;
+        }
+      else if (fmt_header.byte_per_sample == 3 * fmt_header.n_channels)
+        {
+          format = GSL_WAVE_FORMAT_SIGNED_24;
+          break;
+        }
+      /* fall through */
     default:
-      WAV_DEBUG ("unrecognized sample width (%u)", fmt_header.bit_per_sample);
+      WAV_DEBUG ("unrecognized sample width (%ubits, %ubytes)", fmt_header.bit_per_sample, fmt_header.byte_per_sample);
       *error_p = BSE_ERROR_FORMAT_UNKNOWN;
       return NULL;
     }
