@@ -1,27 +1,25 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1997-2004 Tim Janik
  * Copyright (C) 2001 Stefan Westerfeld
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #ifndef __BSE_MATH_H__
 #define __BSE_MATH_H__
 
 #include <bse/bsedefs.h>
-#include <bse/bseieee754.h> /* provides math.h */
+#include <bse/bseieee754.h> 	/* provides math.h */
 
 G_BEGIN_DECLS
 
@@ -39,6 +37,7 @@ G_BEGIN_DECLS
 #define BSE_LN2                       (0.6931471805599453094172321214581765680755)   // ln(2)
 #define BSE_SQRT2                     (1.41421356237309504880168872420969807857)     // sqrt(2)
 #define BSE_1_DIV_SQRT2               (0.7071067811865475244008443621048490392848)   // 1/sqrt(2)
+#define BSE_LN4                       (1.386294361119890618834464242916353136151)    // ln(4)
 #define BSE_LN10                      (2.302585092994045684017991454684364207601)    // ln(10)
 #define BSE_LOG2_10                   (3.321928094887362347870319429489390175865)    // log_2(10)
 #define BSE_LOG2POW20_10              (0.1660964047443681173935159714744695087932)   // log_2(10)/20
@@ -47,6 +46,10 @@ G_BEGIN_DECLS
 #define BSE_LN_2_POW_1_DIV_1200_d     (5.776226504666210911810267678818138067296e-4) // ln(2^(1/1200))
 #define BSE_2_POW_1_DIV_72            (1.009673533228510862192521401118605073603)    // 2^(1/72)
 #define BSE_LN_2_POW_1_DIV_72         (9.62704417444368485301711279803023011216e-3)  // ln(2^(1/72))
+#define BSE_DECIBEL20_FACTOR          (8.68588963806503655302257837833210164588794)  // 20.0 / ln (10.0)
+#define BSE_DECIBEL10_FACTOR          (4.34294481903251827651128918916605082294397)  // 10.0 / ln (10.0)
+#define BSE_1_DIV_DECIBEL20_FACTOR    (0.1151292546497022842008995727342182103801)   // ln (10) / 20
+#define BSE_COMPLEX_ONE               (bse_complex (1, 0))
 
 /* --- structures --- */
 typedef struct {
