@@ -1,21 +1,19 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1997-2004 Tim Janik
  * Copyright (C) 2001 Stefan Westerfeld
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #ifndef __BSE_SIGNAL_H__
 #define __BSE_SIGNAL_H__
@@ -401,8 +399,20 @@ double        bse_transpose_factor           (BseMusicalTuningType musical_tunin
                                               int                  index /* [-132..+132] */);
 
 /* --- cents (1/100th of a semitone) --- */
-extern const double * const bse_cent_table;
-#define	bse_cent_factor(index /* -100..+100 */)		(bse_cent_table[index])
+
+double                  bse_cent_tune (double fine_tune);
+
+/**
+ * @param fine_tune	fine tuning in cent between -100 and 100
+ * @return		a factor corresponding to this
+ *
+ * This function computes a factor which corresponds to a given fine tuning in
+ * cent.  The result can be used as factor for the frequency or the play speed.
+ * It is a faster alternative to bse_cent_tune(), and can only deal with
+ * integer values between -100 and 100. The input is always CLAMPed to ensure
+ * that it lies in this range.
+ */
+static inline double	bse_cent_tune_fast (int fine_tune /* -100..+100 */)   G_GNUC_CONST;
 
 /* --- implementation details --- */
 static inline double  G_GNUC_CONST
@@ -707,6 +717,14 @@ bse_saturate_branching (double value,
 
 void    _bse_init_signal (void);
 
+static inline double G_GNUC_CONST
+bse_cent_tune_fast (int fine_tune)
+{
+  extern const double * const bse_cent_table;
+
+  return bse_cent_table[CLAMP (fine_tune, -100, 100)];
+}
+
 G_END_DECLS
 
 #endif /* __BSE_SIGNAL_H__ */
