@@ -1,26 +1,25 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1996-1999, 2000-2003 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsemididecoder.h"
 #include "bsemidireceiver.h"
 #include "bseengine.h"
 #include <string.h>
 
-static BIRNET_MSG_TYPE_DEFINE (debug_midi_decoder, "midi-decoder", BIRNET_MSG_DEBUG, NULL);
+static SFI_MSG_TYPE_DEFINE (debug_midi_decoder, "midi-decoder", SFI_MSG_DEBUG, NULL);
 #define DEBUG(...)      sfi_debug (debug_midi_decoder, __VA_ARGS__)
 
 /* --- prototypes --- */
@@ -29,12 +28,14 @@ static void     bse_midi_decoder_construct_event   (BseMidiDecoder *self);
 
 /* --- function --- */
 BseMidiDecoder*
-bse_midi_decoder_new (gboolean auto_queue,
-                      gboolean smf_support)
+bse_midi_decoder_new (gboolean             auto_queue,
+                      gboolean             smf_support,
+                      BseMusicalTuningType musical_tuning)
 {
   BseMidiDecoder *self;
   
   self = g_new0 (BseMidiDecoder, 1);
+  self->musical_tuning = musical_tuning;
   self->auto_queue = auto_queue != FALSE;
   self->smf_support = smf_support != FALSE;
   self->state_changed = FALSE;
@@ -363,7 +364,7 @@ midi_decoder_extract_specific (BseMidiDecoder *self,
     case BSE_MIDI_KEY_PRESSURE: /* 7bit note, 7bit intensity */
       if (self->n_bytes < 2)
         return FALSE;
-      event->data.note.frequency = bse_note_to_freq (self->bytes[0] & 0x7f);
+      event->data.note.frequency = bse_note_to_freq (self->musical_tuning, self->bytes[0] & 0x7f);
       ival = self->bytes[1] & 0x7f;
       /* in running-mode, 0 velocity indicates note-off */
       if (event->status == BSE_MIDI_NOTE_ON && ival == 0)
