@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1997-1999, 2000-2003 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bseobject.h"
 
@@ -635,16 +634,22 @@ object_restore_private (BseObject      *object,
 }
 
 static void
-object_restore_finish (BseObject      *object)
+object_restore_finish (BseObject      *object,
+                       guint           vmajor,
+                       guint           vminor,
+                       guint           vmicro)
 {
 }
 
 void
-bse_object_restore_finish (BseObject *object)
+bse_object_restore_finish (BseObject *object,
+                           guint      vmajor,
+                           guint      vminor,
+                           guint      vmicro)
 {
   if (BSE_OBJECT_IN_RESTORE (object))
     {
-      BSE_OBJECT_GET_CLASS (object)->restore_finish (object);
+      BSE_OBJECT_GET_CLASS (object)->restore_finish (object, vmajor, vminor, vmicro);
       BSE_OBJECT_UNSET_FLAGS (object, BSE_OBJECT_FLAG_IN_RESTORE);
     }
 }
