@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2002-2003 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsepart.h"
 #include "bsemain.h"
@@ -22,6 +21,7 @@
 #include "bsetrack.h"
 #include <sfi/gbsearcharray.h>
 #include "gslcommon.h"
+#include "bsemathsignal.h" // bse_semitone_table
 #include "bseieee754.h"
 #include <stdlib.h>
 #include <string.h>
@@ -142,6 +142,7 @@ bse_part_class_init (BsePartClass *class)
 static void
 bse_part_init (BsePart *self)
 {
+  self->semitone_table = bse_semitone_table_from_tuning (BSE_MUSICAL_TUNING_12_TET);
   self->n_ids = 0;
   self->ids = NULL;
   self->last_id = 0;
@@ -260,6 +261,15 @@ bse_part_finalize (GObject *object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+void
+bse_part_set_semitone_table (BsePart      *self,
+                             const double *semitone_table)
+{
+  g_return_if_fail (BSE_IS_PART (self));
+  g_return_if_fail (semitone_table != NULL);
+  self->semitone_table = semitone_table;
+}
+
 static guint
 bse_part_alloc_id (BsePart *self,
 		   guint    tick)
