@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2004 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsepcmdevice-null.h"
 #include "bsesequencer.h"
@@ -27,6 +26,7 @@ typedef struct
 {
   BsePcmHandle handle;
   guint        busy_us;
+  guint        sleep_us;
 } NullHandle;
 
 /* --- prototypes --- */
@@ -74,6 +74,10 @@ bse_pcm_device_null_open (BseDevice     *device,
   handle->check_io = null_device_check_io;
   handle->latency = null_device_latency;
   null->busy_us = 0;
+  if (n_args == 1 && strcmp (args[0], "nosleep") == 0)
+    null->sleep_us = 0;
+  else
+    null->sleep_us = 10 * 1000;
   BSE_PCM_DEVICE (device)->handle = handle;
   DEBUG ("NULL: opening PCM readable=%d writable=%d: %s", require_readable, require_writable, bse_error_blurb (BSE_ERROR_NONE));
   return BSE_ERROR_NONE;
@@ -124,7 +128,8 @@ null_device_write (BsePcmHandle *handle,
     {
       null->busy_us = 0;
       /* give cpu to other applications (we might run at nice level -20) */
-      g_usleep (10 * 1000);
+      if (null->sleep_us)
+        g_usleep (null->sleep_us);
     }
 }
 
@@ -137,10 +142,13 @@ bse_pcm_device_null_class_init (BsePcmDeviceNullClass *class)
   bse_device_class_setup (device_class,
                           -1,
                           "null",
-                          NULL, /* syntax */
+                          _("[nosleep]"), /* syntax */
                           /* TRANSLATORS: keep this text to 70 chars in width */
                           _("Discard all PCM output and provide zero blocks as input. This\n"
-                            "driver is not part of the automatic PCM device selection list."));
+                            "driver is not part of the automatic PCM device selection list.\n"
+                            "Normally the null driver sleeps regularily to give CPU cycles to\n"
+                            "other apps, which is helpful when running at high priority.\n"
+                            "Sleeping can be disabled by passing \"nosleep\" as option.\n"));
   device_class->open = bse_pcm_device_null_open;
   device_class->close = bse_pcm_device_null_close;
 }
