@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1998-1999, 2000-2005 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bseproject.h"
 
@@ -650,16 +649,25 @@ bse_project_lookup_typed_item (BseProject  *self,
 BseWaveRepo*
 bse_project_get_wave_repo (BseProject *self)
 {
-  GSList *slist;
-
   g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
-
+  GSList *slist;
   for (slist = self->supers; slist; slist = slist->next)
     if (BSE_IS_WAVE_REPO (slist->data))
       return slist->data;
   return NULL;
 }
 
+BseSong*
+bse_project_get_song (BseProject *self)
+{
+  g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
+  GSList *slist;
+  for (slist = self->supers; slist; slist = slist->next)
+    if (BSE_IS_SONG (slist->data))
+      return slist->data;
+  return NULL;
+}
+
 static gboolean
 project_check_restore (BseContainer *container,
 		       const gchar  *child_type)
@@ -911,7 +919,7 @@ bse_project_stop_playback (BseProject *self)
       BseSuper *super = BSE_SUPER (slist->data);
       if (BSE_IS_SONG (super))
         bse_sequencer_remove_song (BSE_SONG (super));
-      if (super->context_handle != ~0 && !BSE_SUPER_NEEDS_CONTEXT (super))
+      if (super->context_handle != ~0 && BSE_SUPER_NEEDS_CONTEXT (super))
 	{
 	  BseSource *source = BSE_SOURCE (super);
 	  bse_source_dismiss_context (source, super->context_handle, trans);
