@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1997-1999, 2000-2004 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsesequencer.h"
 #include "gslcommon.h"
@@ -29,6 +28,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <string.h>
 #include <vector>
 
 /* due to a linker/compiler bug on SuSE 9.2, we need to
@@ -39,8 +39,8 @@ extern "C" { BirnetThread *bse_sequencer_thread = NULL; }
 
 using namespace std;
 
-static SFI_MSG_TYPE_DEFINE (debug_sequencer, "sequencer", SFI_MSG_DEBUG, NULL);
-#define DEBUG(...)      sfi_debug (debug_sequencer, __VA_ARGS__)
+#define CHECKTRACE()    UNLIKELY (bse_trace_args.sequencer)
+#define SEQTRACE(...)   do { if (CHECKTRACE()) sfi_debug_channel_printf (bse_trace_args.sequencer, NULL, __VA_ARGS__); } while (0)
 
 #define	BSE_SEQUENCER_FUTURE_BLOCKS    (7)
 
@@ -404,7 +404,7 @@ bse_sequencer_thread_lagging (guint n_blocks)
 static void
 bse_sequencer_thread_main (gpointer data)
 {
-  DEBUG ("SST: start\n");
+  SEQTRACE ("SEQ:thrdstrt: now=%llu", gsl_tick_stamp());
   sfi_thread_set_wakeup (sequencer_wake_up, NULL, NULL);
   bse_message_setup_thread_handler();
   BSE_SEQUENCER_LOCK ();
@@ -417,16 +417,27 @@ bse_sequencer_thread_main (gpointer data)
       for (ring = global_sequencer->songs; ring; ring = sfi_ring_walk (ring, global_sequencer->songs))
 	{
           BseSong *song = BSE_SONG (ring->data);
-          if (!song->sequencer_start_SL && song->sequencer_start_request_SL <= cur_stamp)
-            song->sequencer_start_SL = cur_stamp;
+          bool forced_ticks = 0;
+          if (!song->sequencer_start_SL && song->sequencer_start_request_SL <= next_stamp + bse_engine_block_size())
+            {
+              song->sequencer_start_SL = next_stamp;
+              forced_ticks = bse_engine_block_size();
+            }
           if (song->sequencer_start_SL && !song->sequencer_done_SL)
             {
               gdouble stamp_diff = (next_stamp - song->sequencer_start_SL) - song->delta_stamp_SL;
               guint64 old_song_pos = bse_dtoll (song->sequencer_start_SL + song->delta_stamp_SL);
               gboolean song_starting = song->delta_stamp_SL == 0;
+              if (UNLIKELY (forced_ticks))
+                stamp_diff = MAX (stamp_diff, 1);
 	      while (stamp_diff > 0)
 		{
 		  guint n_ticks = bse_dtoi (stamp_diff * song->tpsi_SL);
+                  if (UNLIKELY (forced_ticks))
+                    {
+                      n_ticks = MAX (n_ticks, forced_ticks);
+                      forced_ticks = 0;
+                    }
 		  if (n_ticks < 1)
 		    break;
 		  bse_sequencer_process_song_SL (song, n_ticks);
@@ -450,7 +461,7 @@ bse_sequencer_thread_main (gpointer data)
     }
   while (bse_sequencer_poll_Lm (-1));
   BSE_SEQUENCER_UNLOCK ();
-  DEBUG ("SST: end\n");
+  SEQTRACE ("SEQ:thrdstop: now=%llu", gsl_tick_stamp());
 }
 
 static void
@@ -544,12 +555,13 @@ bse_sequencer_process_track_SL (BseTrack        *track,
   if (!part && next)
     {
       part = bse_track_get_part_SL (track, next, &start, &next);
-      // DEBUG ("track[%u]: advancing to first part: %p", start_tick, part);
+      SEQTRACE ("SEQ:trackjmp: tick=%u fast forward to first part part=%p now=%llu", start_tick, part, gsl_tick_stamp());
     }
   if (!part || (next == 0 && start + part->last_tick_SL < start_tick))
     {
-      DEBUG ("track[%u]: could be done: %p==NULL || %u < %u (next=%u)", start_tick, part, start + (part ? part->last_tick_SL : 0), start_tick, next);
       track->track_done_SL = !bse_midi_receiver_voices_pending (midi_receiver, track->midi_channel_SL);
+      SEQTRACE ("SEQ:trackchk: tick=%u next=%u part=%p done=%u now=%llu", // part==NULL || start + (part ? part->last_tick_SL : 0) < start_tick
+                start_tick, next, part, track->track_done_SL, gsl_tick_stamp());
       part = NULL;
     }
   while (part && start < bound)
@@ -599,9 +611,13 @@ bse_sequencer_process_part_SL (BsePart         *part,
                                           freq);
           bse_midi_receiver_push_event (midi_receiver, eon);
           bse_midi_receiver_push_event (midi_receiver, eoff);
-          DEBUG ("note: %llu till %llu freq=%f (note=%d velocity=%f)",
-                 eon->delta_time, eoff->delta_time, freq,
-                 note->note, note->velocity);
+          if (CHECKTRACE())
+            {
+              SEQTRACE ("SEQ:note-on:  tick=%llu midinote=%-3d velocity=%02x freq=% 10f now=%llu",
+                        eon->delta_time,  note->note, bse_ftoi (note->velocity * 128), freq, gsl_tick_stamp());
+              SEQTRACE ("SEQ:note-off: tick=%llu midinote=%-3d velocity=%02x freq=% 10f now=%llu",
+                        eoff->delta_time, note->note, bse_ftoi (note->velocity * 128), freq, gsl_tick_stamp());
+            }
           note++;
         }
     }
@@ -617,8 +633,8 @@ bse_sequencer_process_part_SL (BsePart         *part,
                                                        bse_dtoull (start_stamp + (node->tick - start_tick) * stamps_per_tick),
                                                        BseMidiSignalType (cev->ctype), cev->value);
           bse_midi_receiver_push_event (midi_receiver, event);
-          DEBUG ("control: %llu signal=%d (value=%f)",
-                 event->delta_time, cev->ctype, cev->value);
+          SEQTRACE ("SEQ:control:  tick=%llu midisignal=%-3d value=%f now=%llu",
+                    event->delta_time, cev->ctype, cev->value, gsl_tick_stamp());
         }
       node++;
     }
