@@ -18,40 +18,40 @@
 #include "bseengine.h"
 #include <string.h>
 
-#line 35 "bsesong.proc"
+#line 33 "bsesong.proc"
 
 /* --- create-bus --- */
 static void
 create_bus_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 36 "bsesong.proc"
+#line 34 "bsesong.proc"
  {
-#line 38 "bsesong.proc"
+#line 36 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("bus", NULL, NULL,
 				 BSE_TYPE_BUS, SFI_PARAM_STANDARD);
-#line 42 "bsesong.proc"
+#line 40 "bsesong.proc"
 }  }
 static BseErrorType
-#line 42 "bsesong.proc"
+#line 40 "bsesong.proc"
 create_bus_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 45 "bsesong.proc"
+#line 43 "bsesong.proc"
 {
-#line 46 "bsesong.proc"
+#line 44 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   BseUndoStack *ustack;
   BseItem *child = NULL;
 
-#line 52 "bsesong.proc"
+#line 50 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 56 "bsesong.proc"
+#line 54 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
@@ -63,7 +63,7 @@ create_bus_exec (BseProcedureClass *proc,
       bse_item_undo_close (ustack);
     }
 
-#line 67 "bsesong.proc"
+#line 65 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -73,54 +73,54 @@ create_bus_exec (BseProcedureClass *proc,
 /* --- remove-bus --- */
 static void
 remove_bus_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 73 "bsesong.proc"
+#line 71 "bsesong.proc"
  {
-#line 75 "bsesong.proc"
+#line 73 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("bus", NULL, NULL,
 				 BSE_TYPE_BUS, SFI_PARAM_STANDARD);
-#line 79 "bsesong.proc"
+#line 77 "bsesong.proc"
 }  }
 static BseErrorType
-#line 79 "bsesong.proc"
+#line 77 "bsesong.proc"
 remove_bus_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 82 "bsesong.proc"
+#line 80 "bsesong.proc"
 {
-#line 83 "bsesong.proc"
+#line 81 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 88 "bsesong.proc"
+#line 86 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_BUS (child) || BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 92 "bsesong.proc"
+#line 90 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 98 "bsesong.proc"
+#line 96 "bsesong.proc"
       
       bse_item_set (child, "master-output", FALSE, NULL);
+#line 98 "bsesong.proc"
+      
+#line 99 "bsesong.proc"
+      bse_container_uncross_undoable (BSE_CONTAINER (self), child);     
 #line 100 "bsesong.proc"
       
-#line 101 "bsesong.proc"
-      bse_container_uncross_undoable (BSE_CONTAINER (self), child);     
+      bse_item_push_redo_proc (self, "remove-bus", child);
 #line 102 "bsesong.proc"
       
-      bse_item_push_redo_proc (self, "remove-bus", child);
-#line 104 "bsesong.proc"
-      
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 106 "bsesong.proc"
+#line 104 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -131,37 +131,37 @@ remove_bus_exec (BseProcedureClass *proc,
 /* --- ensure-master-bus --- */
 static void
 ensure_master_bus_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 113 "bsesong.proc"
+#line 111 "bsesong.proc"
  {
-#line 115 "bsesong.proc"
+#line 113 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("bus", NULL, NULL,
 				 BSE_TYPE_BUS, SFI_PARAM_STANDARD);
-#line 119 "bsesong.proc"
+#line 117 "bsesong.proc"
 }  }
 static BseErrorType
-#line 119 "bsesong.proc"
+#line 117 "bsesong.proc"
 ensure_master_bus_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 122 "bsesong.proc"
+#line 120 "bsesong.proc"
 {
-#line 123 "bsesong.proc"
+#line 121 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseSource *child;
 
-#line 127 "bsesong.proc"
+#line 125 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 131 "bsesong.proc"
+#line 129 "bsesong.proc"
   
   child = bse_song_ensure_master (self);
 
-#line 134 "bsesong.proc"
+#line 132 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -171,36 +171,36 @@ ensure_master_bus_exec (BseProcedureClass *proc,
 /* --- get-master-bus --- */
 static void
 get_master_bus_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 140 "bsesong.proc"
+#line 138 "bsesong.proc"
  {
-#line 142 "bsesong.proc"
+#line 140 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("bus", NULL, NULL,
 				 BSE_TYPE_BUS, SFI_PARAM_STANDARD);
-#line 146 "bsesong.proc"
+#line 144 "bsesong.proc"
 }  }
 static BseErrorType
-#line 146 "bsesong.proc"
+#line 144 "bsesong.proc"
 get_master_bus_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 149 "bsesong.proc"
+#line 147 "bsesong.proc"
 {
-#line 150 "bsesong.proc"
+#line 148 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
 
-#line 153 "bsesong.proc"
+#line 151 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 157 "bsesong.proc"
+#line 155 "bsesong.proc"
   
   BseBus *bus = bse_song_find_master (self);
 
-#line 160 "bsesong.proc"
+#line 158 "bsesong.proc"
   
   bse_value_set_object (out_values++, bus);
   
@@ -210,7 +210,7 @@ get_master_bus_exec (BseProcedureClass *proc,
 static const gchar*
 orphans_track_name (void)
 {
-#line 169 "bsesong.proc"
+#line 167 "bsesong.proc"
   
   return _("Orphan Parts");
 }
@@ -224,14 +224,14 @@ bse_song_ensure_orphans_track_noundo (BseSong *self)
       BseTrack *track = ring->data;
       gboolean muted = FALSE;
       g_object_get (track, "muted", &muted, NULL);
-#line 184 "bsesong.proc"
+#line 182 "bsesong.proc"
       if (muted && g_object_get_data (track, "BseSong-orphan-track") == bse_song_ensure_orphans_track_noundo) 
         return track;
     }
   gpointer child = bse_container_new_child_bname (BSE_CONTAINER (self), BSE_TYPE_TRACK, orphans_track_name(), NULL);
-#line 188 "bsesong.proc"
+#line 186 "bsesong.proc"
   g_object_set (child, "muted", TRUE, NULL); 
-#line 189 "bsesong.proc"
+#line 187 "bsesong.proc"
   g_object_set_data (child, "BseSong-orphan-track", bse_song_ensure_orphans_track_noundo); 
   return child;
 }
@@ -241,7 +241,7 @@ bse_song_find_first_track (BseSong *self,
                            BsePart *part)
 {
   SfiRing *ring;
-#line 198 "bsesong.proc"
+#line 196 "bsesong.proc"
   
   for (ring = self->tracks_SL; ring; ring = sfi_ring_walk (ring, self->tracks_SL))
     {
@@ -256,30 +256,30 @@ bse_song_find_first_track (BseSong *self,
 /* --- ensure-track-links --- */
 static void
 ensure_track_links_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 209 "bsesong.proc"
+#line 207 "bsesong.proc"
  {
-#line 211 "bsesong.proc"
+#line 209 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
-#line 213 "bsesong.proc"
+#line 211 "bsesong.proc"
 }  }
 static BseErrorType
-#line 213 "bsesong.proc"
+#line 211 "bsesong.proc"
 ensure_track_links_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 216 "bsesong.proc"
+#line 214 "bsesong.proc"
 {
-#line 217 "bsesong.proc"
+#line 215 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
 
-#line 220 "bsesong.proc"
+#line 218 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 224 "bsesong.proc"
+#line 222 "bsesong.proc"
   
   gboolean clear_undo = FALSE;
   SfiRing *ring;
@@ -303,41 +303,41 @@ ensure_track_links_exec (BseProcedureClass *proc,
 /* --- create-part --- */
 static void
 create_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 244 "bsesong.proc"
+#line 242 "bsesong.proc"
  {
-#line 246 "bsesong.proc"
+#line 244 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("part", NULL, NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
-#line 250 "bsesong.proc"
+#line 248 "bsesong.proc"
 }  }
 static BseErrorType
-#line 250 "bsesong.proc"
+#line 248 "bsesong.proc"
 create_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 253 "bsesong.proc"
+#line 251 "bsesong.proc"
 {
-#line 254 "bsesong.proc"
+#line 252 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseUndoStack *ustack;
   BseItem *child;
 
-#line 259 "bsesong.proc"
+#line 257 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 263 "bsesong.proc"
+#line 261 "bsesong.proc"
   
   ustack = bse_item_undo_open (self, "create-part");
   child = bse_container_new_child (BSE_CONTAINER (self), BSE_TYPE_PART, NULL);
   bse_item_push_undo_proc (self, "remove-part", child);
   bse_item_undo_close (ustack);
   
-#line 269 "bsesong.proc"
+#line 267 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -347,50 +347,50 @@ create_part_exec (BseProcedureClass *proc,
 /* --- remove-part --- */
 static void
 remove_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 275 "bsesong.proc"
+#line 273 "bsesong.proc"
  {
-#line 277 "bsesong.proc"
+#line 275 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
-#line 281 "bsesong.proc"
+#line 279 "bsesong.proc"
 }  }
 static BseErrorType
-#line 281 "bsesong.proc"
+#line 279 "bsesong.proc"
 remove_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 284 "bsesong.proc"
+#line 282 "bsesong.proc"
 {
-#line 285 "bsesong.proc"
+#line 283 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 290 "bsesong.proc"
+#line 288 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (child) || BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 294 "bsesong.proc"
+#line 292 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 300 "bsesong.proc"
+#line 298 "bsesong.proc"
       
       bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 302 "bsesong.proc"
+#line 300 "bsesong.proc"
       
       bse_item_push_redo_proc (self, "remove-part", child);
-#line 304 "bsesong.proc"
+#line 302 "bsesong.proc"
       
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 306 "bsesong.proc"
+#line 304 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -401,34 +401,34 @@ remove_part_exec (BseProcedureClass *proc,
 /* --- create-track --- */
 static void
 create_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 313 "bsesong.proc"
+#line 311 "bsesong.proc"
  {
-#line 315 "bsesong.proc"
+#line 313 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 319 "bsesong.proc"
+#line 317 "bsesong.proc"
 }  }
 static BseErrorType
-#line 319 "bsesong.proc"
+#line 317 "bsesong.proc"
 create_track_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 322 "bsesong.proc"
+#line 320 "bsesong.proc"
 {
-#line 323 "bsesong.proc"
+#line 321 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   BseItem *child = NULL;
 
-#line 328 "bsesong.proc"
+#line 326 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 332 "bsesong.proc"
+#line 330 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
@@ -440,7 +440,7 @@ create_track_exec (BseProcedureClass *proc,
       bse_item_undo_close (ustack);
     }
 
-#line 343 "bsesong.proc"
+#line 341 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -450,51 +450,51 @@ create_track_exec (BseProcedureClass *proc,
 /* --- remove-track --- */
 static void
 remove_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 349 "bsesong.proc"
+#line 347 "bsesong.proc"
  {
-#line 351 "bsesong.proc"
+#line 349 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 355 "bsesong.proc"
+#line 353 "bsesong.proc"
 }  }
 static BseErrorType
-#line 355 "bsesong.proc"
+#line 353 "bsesong.proc"
 remove_track_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 358 "bsesong.proc"
+#line 356 "bsesong.proc"
 {
-#line 359 "bsesong.proc"
+#line 357 "bsesong.proc"
   
   BseSong *self  = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 364 "bsesong.proc"
+#line 362 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_TRACK (child) ||
       BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 369 "bsesong.proc"
+#line 367 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 375 "bsesong.proc"
+#line 373 "bsesong.proc"
       
       bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 377 "bsesong.proc"
+#line 375 "bsesong.proc"
       
       bse_item_push_redo_proc (self, "remove-track", child);
-#line 379 "bsesong.proc"
+#line 377 "bsesong.proc"
       
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 381 "bsesong.proc"
+#line 379 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -505,25 +505,25 @@ remove_track_exec (BseProcedureClass *proc,
 /* --- find-track-for-part --- */
 static void
 find_track_for_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 388 "bsesong.proc"
+#line 386 "bsesong.proc"
  {
-#line 390 "bsesong.proc"
+#line 388 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 396 "bsesong.proc"
+#line 394 "bsesong.proc"
 }  }
 static BseErrorType
-#line 396 "bsesong.proc"
+#line 394 "bsesong.proc"
 find_track_for_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 399 "bsesong.proc"
+#line 397 "bsesong.proc"
 {
-#line 400 "bsesong.proc"
+#line 398 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BsePart *part = bse_value_get_object (in_values++);
@@ -531,13 +531,13 @@ find_track_for_part_exec (BseProcedureClass *proc,
   guint tick = 0;
   SfiRing *ring;
 
-#line 407 "bsesong.proc"
+#line 405 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (part) ||
       BSE_ITEM (part)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 412 "bsesong.proc"
+#line 410 "bsesong.proc"
   
   for (ring = self->tracks_SL; ring; ring = sfi_ring_walk (ring, self->tracks_SL))
     {
@@ -551,7 +551,7 @@ find_track_for_part_exec (BseProcedureClass *proc,
 	}
     }
 
-#line 425 "bsesong.proc"
+#line 423 "bsesong.proc"
   
   bse_value_set_object (out_values++, track);
   
@@ -561,36 +561,36 @@ find_track_for_part_exec (BseProcedureClass *proc,
 /* --- find-any-track-for-part --- */
 static void
 find_any_track_for_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 431 "bsesong.proc"
+#line 429 "bsesong.proc"
  {
-#line 433 "bsesong.proc"
+#line 431 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 439 "bsesong.proc"
+#line 437 "bsesong.proc"
 }  }
 static BseErrorType
-#line 439 "bsesong.proc"
+#line 437 "bsesong.proc"
 find_any_track_for_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 442 "bsesong.proc"
+#line 440 "bsesong.proc"
 {
-#line 443 "bsesong.proc"
+#line 441 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BsePart *part = bse_value_get_object (in_values++);
 
-#line 447 "bsesong.proc"
+#line 445 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (part) ||
       BSE_ITEM (part)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 452 "bsesong.proc"
+#line 450 "bsesong.proc"
   
   bse_value_set_object (out_values++, bse_song_find_first_track (self, part));
   
@@ -600,9 +600,9 @@ find_any_track_for_part_exec (BseProcedureClass *proc,
 /* --- synthesize-note --- */
 static void
 synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 458 "bsesong.proc"
+#line 456 "bsesong.proc"
  {
-#line 460 "bsesong.proc"
+#line 458 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
@@ -615,16 +615,16 @@ synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
   *(in_pspecs++)    = sfi_pspec_real ("velocity", "Velocity", NULL,
 			  1.0, 0, 1.0, 0.01,
 			  SFI_PARAM_STANDARD ":scale");
-#line 472 "bsesong.proc"
+#line 470 "bsesong.proc"
 }  }
 static BseErrorType
-#line 472 "bsesong.proc"
+#line 470 "bsesong.proc"
 synthesize_note_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 475 "bsesong.proc"
+#line 473 "bsesong.proc"
 {
-#line 476 "bsesong.proc"
+#line 474 "bsesong.proc"
   
   BseSong *self      = bse_value_get_object (in_values++);
   BseTrack *track    = bse_value_get_object (in_values++);
@@ -633,19 +633,18 @@ synthesize_note_exec (BseProcedureClass *proc,
   gint     fine_tune = sfi_value_get_int (in_values++);
   gfloat   velocity  = sfi_value_get_real (in_values++);
   
-#line 484 "bsesong.proc"
+#line 482 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_TRACK (track) ||
       BSE_ITEM (track)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 489 "bsesong.proc"
+#line 487 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self) && self->midi_receiver_SL)
     {
-      gfloat freq = BSE_KAMMER_FREQUENCY *
-		    BSE_SEMITONE_FACTOR (note) *
-		    BSE_FINE_TUNE_FACTOR (fine_tune);
+      double semitone_factor = bse_transpose_factor (self->musical_tuning, CLAMP (note, SFI_MIN_NOTE, SFI_MAX_NOTE) - SFI_KAMMER_NOTE);
+      double freq = BSE_KAMMER_FREQUENCY * semitone_factor * bse_cent_tune_fast (fine_tune);
       SfiTime tstamp = gsl_tick_stamp () + bse_engine_block_size () * 2;
       BseMidiEvent *eon, *eoff;
       eon  = bse_midi_event_note_on (track->midi_channel_SL, tstamp, freq, velocity);
@@ -662,37 +661,37 @@ synthesize_note_exec (BseProcedureClass *proc,
 /* --- get-timing --- */
 static void
 get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 508 "bsesong.proc"
+#line 505 "bsesong.proc"
  {
-#line 510 "bsesong.proc"
+#line 507 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL, BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("tick", "Tick", "Tick to retrieve timing info about", 0, 0, G_MAXINT, 384, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("timing", "Timing", "Song Timing", BSE_TYPE_SONG_TIMING, SFI_PARAM_STANDARD);
-#line 513 "bsesong.proc"
+#line 510 "bsesong.proc"
 }  }
 static BseErrorType
-#line 513 "bsesong.proc"
+#line 510 "bsesong.proc"
 get_timing_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 516 "bsesong.proc"
+#line 513 "bsesong.proc"
 {
-#line 517 "bsesong.proc"
+#line 514 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   SfiInt   tick = sfi_value_get_int (in_values++);
   BseSongTiming timing = { 0, };
 
-#line 522 "bsesong.proc"
+#line 519 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 526 "bsesong.proc"
+#line 523 "bsesong.proc"
   
   bse_song_get_timing (self, tick, &timing);
 
-#line 529 "bsesong.proc"
+#line 526 "bsesong.proc"
   
   bse_value_set_boxed (out_values++, &timing);
   
@@ -705,7 +704,7 @@ __enode_create_bus__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Create a new mixer bus for a Song.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 37;
+  es->line = 35;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -724,7 +723,7 @@ __enode_remove_bus__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Delete a mixer bus from a Song.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 74;
+  es->line = 72;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -743,7 +742,7 @@ __enode_ensure_master_bus__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Retrieve master output bus of a song, will create one if it doesn't exist.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 114;
+  es->line = 112;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -762,7 +761,7 @@ __enode_get_master_bus__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Retrieve master output bus of a song if it exists.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 141;
+  es->line = 139;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -781,7 +780,7 @@ __enode_ensure_track_links__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Ensure that each part in a song is inserted into at least one track.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 210;
+  es->line = 208;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -800,7 +799,7 @@ __enode_create_part__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Create a new Part in a Song.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 245;
+  es->line = 243;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -819,7 +818,7 @@ __enode_remove_part__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Delete a Part from a Song.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 276;
+  es->line = 274;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -838,7 +837,7 @@ __enode_create_track__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Create a new Track for a Song.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 314;
+  es->line = 312;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -857,7 +856,7 @@ __enode_remove_track__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Delete a Track from a Song.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 350;
+  es->line = 348;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -876,7 +875,7 @@ __enode_find_track_for_part__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Find a track suitable for playing notes of a given part.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 389;
+  es->line = 387;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -895,7 +894,7 @@ __enode_find_any_track_for_part__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Find the first track that contains part, suitable to check for orphan parts.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 432;
+  es->line = 430;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -914,7 +913,7 @@ __enode_synthesize_note__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Synthesize a note on a song of an active project.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 459;
+  es->line = 457;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
@@ -933,7 +932,7 @@ __enode_get_timing__fill_strings (BseExportStrings *es)
 {
   es->blurb = _("Retrieve song timing information at a specific tick.");
   es->file = "/opt/src/beast/bse/bsesong.proc";
-  es->line = 509;
+  es->line = 506;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
