@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2002-2003 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsetrack.h"
 
@@ -33,7 +32,7 @@
 #include "bsewaverepo.h"
 #include <string.h>
 
-static BIRNET_MSG_TYPE_DEFINE (debug_xref, "xref", BIRNET_MSG_DEBUG, NULL);
+static SFI_MSG_TYPE_DEFINE (debug_xref, "xref", SFI_MSG_DEBUG, NULL);
 #define XREF_DEBUG(...) sfi_debug (debug_xref, __VA_ARGS__)
 
 #define upper_power2(uint_n)	sfi_alloc_upper_power2 (MAX ((uint_n), 4))
@@ -341,7 +340,7 @@ create_wnet (BseTrack *self,
   g_return_if_fail (self->wnet == NULL);
 
   const gchar *play_type = bse_xinfos_get_value (wave->xinfos, "play-type");
-  const gchar *synthesis_network = play_type ? play_type : "wave-mono";
+  const gchar *synthesis_network = play_type ? play_type : "adsr-wave-1";
 
   self->wnet = bse_project_create_intern_synth (bse_item_get_project (BSE_ITEM (self)),
 						synthesis_network,
@@ -354,12 +353,23 @@ create_wnet (BseTrack *self,
 		  "snet", self->wnet,
 		  NULL);
 
-  if (strcmp (synthesis_network, "wave-mono") == 0)
+  if (strcmp (synthesis_network, "adsr-wave-1") == 0 ||
+      strcmp (synthesis_network, "plain-wave-1") == 0)
     {
       g_object_set (bse_container_resolve_upath (BSE_CONTAINER (self->wnet), "wave-osc"), /* no undo */
 						 "wave", wave,
 					         NULL);
     }
+  else if (strcmp (synthesis_network, "adsr-wave-2") == 0 ||
+           strcmp (synthesis_network, "plain-wave-2") == 0)
+    {
+      g_object_set (bse_container_resolve_upath (BSE_CONTAINER (self->wnet), "wave-osc-left"), /* no undo */
+						 "wave", wave,
+					         NULL);
+      g_object_set (bse_container_resolve_upath (BSE_CONTAINER (self->wnet), "wave-osc-right"), /* no undo */
+						 "wave", wave,
+					         NULL);
+    }
   else if (strcmp (synthesis_network, "gus-patch") == 0)
     {
       g_object_set (bse_container_resolve_upath (BSE_CONTAINER (self->wnet), "wave-osc"), /* no undo */
@@ -1011,7 +1021,7 @@ bse_track_class_init (BseTrackClass *class)
 						     SFI_PARAM_STANDARD ":unprepared"));
   bse_object_class_add_param (object_class, _("Synth Input"),
 			      PROP_N_VOICES,
-			      sfi_pspec_int ("n_voices", _("Max Voixes"), _("Maximum number of voices for simultaneous playback"),
+			      sfi_pspec_int ("n_voices", _("Max Voices"), _("Maximum number of voices for simultaneous playback"),
 					     16, 1, 256, 1,
 					     SFI_PARAM_GUI SFI_PARAM_STORAGE ":scale:unprepared"));
   bse_object_class_add_param (object_class, _("MIDI Instrument"),
