@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1998-2002 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "topconfig.h"
 #include "bseutils.h"
@@ -31,23 +30,27 @@
 
 /* --- record utils --- */
 BseNoteDescription*
-bse_note_description (SfiInt note,
-                      gint   fine_tune)
+bse_note_description (BseMusicalTuningType   musical_tuning,
+                      int                    note,
+                      int                    fine_tune)
 {
   BseNoteDescription *info = bse_note_description_new ();
 
+  info->musical_tuning = musical_tuning;
   if (note >= BSE_MIN_NOTE && note <= BSE_MAX_NOTE)
     {
       gchar letter;
       info->note = note;
+      gboolean black_semitone = false;
       bse_note_examine (info->note,
                         &info->octave,
                         &info->semitone,
-                        &info->upshift,
+                        &black_semitone,
                         &letter);
+      info->upshift = black_semitone;
       info->letter = letter;
       info->fine_tune = CLAMP (fine_tune, BSE_MIN_FINE_TUNE, BSE_MAX_FINE_TUNE);
-      info->freq = bse_note_to_tuned_freq (info->note, info->fine_tune);
+      info->freq = bse_note_to_tuned_freq (musical_tuning, info->note, info->fine_tune);
       info->name = bse_note_to_string (info->note);
       info->max_fine_tune = BSE_MAX_FINE_TUNE;
       info->kammer_note = BSE_KAMMER_NOTE;
@@ -289,8 +292,8 @@ bse_icon_from_pixdata (const BsePixdata *pixdata)
   if (pixdata->width < 1 || pixdata->width > 128 ||
       pixdata->height < 1 || pixdata->height > 128)
     {
-      g_warning (G_GNUC_PRETTY_FUNCTION "(): `pixdata' exceeds dimension limits (%ux%u)",
-		 pixdata->width, pixdata->height);
+      g_warning ("%s(): `pixdata' exceeds dimension limits (%ux%u)",
+                 BIRNET_PRETTY_FUNCTION, pixdata->width, pixdata->height);
       return NULL;
     }
   bpp = pixdata->type & BSE_PIXDATA_RGB_MASK;
@@ -298,7 +301,8 @@ bse_icon_from_pixdata (const BsePixdata *pixdata)
   if ((bpp != BSE_PIXDATA_RGB && bpp != BSE_PIXDATA_RGBA) ||
       (encoding && encoding != BSE_PIXDATA_1BYTE_RLE))
     {
-      g_warning (G_GNUC_PRETTY_FUNCTION "(): `pixdata' format/encoding unrecognized");
+      g_warning ("%s(): `pixdata' format/encoding unrecognized",
+                 BIRNET_PRETTY_FUNCTION);
       return NULL;
     }
   if (!pixdata->encoded_pix_data)
@@ -353,7 +357,7 @@ bse_icon_from_pixdata (const BsePixdata *pixdata)
 	      rle_buffer += length;
 	    }
           if (check_overrun)
-            g_warning (G_GNUC_PRETTY_FUNCTION "(): `pixdata' encoding screwed");
+            g_warning ("%s(): `pixdata' encoding screwed", BIRNET_PRETTY_FUNCTION);
         }
     }
   else
