@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 1997-1999, 2000-2005 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsewave.h"
 #include "bsemain.h"
@@ -23,6 +22,7 @@
 #include "gsldatahandle.h"
 #include "bseserver.h"
 #include "bseloader.h"
+#include "topconfig.h"
 
 #include <string.h>
 
@@ -275,7 +275,32 @@ bse_wave_load_wave_file (BseWave      *self,
 
   bse_wave_clear (self);
 
-  BseWaveFileInfo *fi = bse_wave_file_info_load (file_name, &error);
+  BseWaveFileInfo *fi = NULL;
+
+  if (!g_path_is_absolute (file_name))	  /* resolve relative path using search dir */
+    {
+      char *sample_path;
+      SfiRing *files, *walk;
+      if (bse_main_args->override_sample_path)
+	sample_path = g_strdup (bse_main_args->override_sample_path);
+      else
+	sample_path = g_path_concat (BSE_PATH_SAMPLES, BSE_GCONFIG (sample_path), NULL);
+      files = sfi_file_crawler_list_files (sample_path, file_name, G_FILE_TEST_IS_REGULAR);
+
+      for (walk = files; walk; walk = sfi_ring_walk (files, walk))
+	{
+	  char *fname = walk->data;
+	  if (!fi)
+	    fi = bse_wave_file_info_load (fname, &error);
+	  g_free (fname);
+	}
+      sfi_ring_free (files);
+      g_free (sample_path);
+    }
+  else
+    {
+      fi = bse_wave_file_info_load (file_name, &error);
+    }
   if (fi)
     {
       guint i = 0;
