@@ -1,19 +1,18 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2001-2003 Tim Janik
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "bsewaveosc.h"
 #include <bse/bsemain.h>
@@ -397,7 +396,7 @@ wosc_process (BseModule *module,
               guint      n_values)
 {
   GslWaveOscData *wosc = module->user_data;
-  gfloat gate;
+  gfloat gate, done;
   
   gsl_wave_osc_process (wosc,
                         n_values,
@@ -410,7 +409,9 @@ wosc_process (BseModule *module,
                         BSE_MODULE_OBUFFER (module, BSE_WAVE_OSC_OCHANNEL_WAVE));
   
   gate = wosc->done ? 0.0 : 1.0;
+  done = wosc->done ? 1.0 : 0.0;
   module->ostreams[BSE_WAVE_OSC_OCHANNEL_GATE].values = bse_engine_const_values (gate);
+  module->ostreams[BSE_WAVE_OSC_OCHANNEL_DONE].values = bse_engine_const_values (done);
 }
 
 static void
@@ -599,4 +600,6 @@ bse_wave_osc_class_init (BseWaveOscClass *class)
   g_assert (ochannel == BSE_WAVE_OSC_OCHANNEL_WAVE);
   ochannel = bse_source_class_add_ochannel (source_class, "gate-out", _("Gate Out"), _("Gate Output"));
   g_assert (ochannel == BSE_WAVE_OSC_OCHANNEL_GATE);
+  ochannel = bse_source_class_add_ochannel (source_class, "done-out", _("Done Out"), _("Done Output"));
+  g_assert (ochannel == BSE_WAVE_OSC_OCHANNEL_DONE);
 }
