@@ -4,17 +4,15 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "gsldatahandle.h"
 
@@ -291,6 +289,35 @@ gsl_data_handle_osc_freq (GslDataHandle *dhandle)
   return f;
 }
 
+gfloat
+gsl_data_handle_volume (GslDataHandle *dhandle)
+{
+  g_return_val_if_fail (dhandle != NULL, 0);
+  g_return_val_if_fail (dhandle->open_count > 0, 0);
+  
+  GSL_SPIN_LOCK (&dhandle->mutex);
+  gfloat f = bse_xinfos_get_float (dhandle->setup.xinfos, "volume");
+  GSL_SPIN_UNLOCK (&dhandle->mutex);
+  
+  /* no (or invalid) volume setting means that we replay without scaling */
+  if (f <= 0 || f > 1.0)
+    f = 1.0;
+  return f;
+}
+
+gfloat
+gsl_data_handle_fine_tune (GslDataHandle *dhandle)
+{
+  g_return_val_if_fail (dhandle != NULL, 0);
+  g_return_val_if_fail (dhandle->open_count > 0, 0);
+
+  GSL_SPIN_LOCK (&dhandle->mutex);
+  gfloat f = bse_xinfos_get_float (dhandle->setup.xinfos, "fine-tune");
+  GSL_SPIN_UNLOCK (&dhandle->mutex);
+
+  return f;
+}
+
 const gchar*
 gsl_data_handle_name (GslDataHandle *dhandle)
 {
@@ -738,6 +765,7 @@ chain_handle_get_state_length (GslDataHandle *dhandle)
   return gsl_data_handle_get_state_length (chandle->src_handle);
 }
 
+
 /* --- reversed handle --- */
 static void
 reverse_handle_destroy (GslDataHandle *dhandle)
@@ -821,6 +849,71 @@ gsl_data_handle_new_reverse (GslDataHandle *src_handle)
 }
 
 
+/* --- scale handle --- */
+typedef struct {
+  GslDataHandle     dhandle;
+  GslDataHandle	   *src_handle;	/* mirror ChainHandle */
+  double            factor;
+} ScaledHandle;
+
+static void
+scale_handle_destroy (GslDataHandle *dhandle)
+{
+  ScaledHandle *shandle = (ScaledHandle*) dhandle;
+  
+  gsl_data_handle_unref (shandle->src_handle);
+  
+  gsl_data_handle_common_free (dhandle);
+  sfi_delete_struct (ScaledHandle, shandle);
+}
+
+static int64
+scale_handle_read (GslDataHandle *dhandle,
+                   int64          voffset,
+                   int64          n_values,
+                   gfloat        *values)
+{
+  ScaledHandle *shandle = (ScaledHandle*) dhandle;
+  int64 i, l = gsl_data_handle_read (shandle->src_handle, voffset, n_values, values);
+  for (i = 0; i < l; i++)
+    values[i] *= shandle->factor;
+  return l;
+}
+
+GslDataHandle*
+gsl_data_handle_new_scale (GslDataHandle *src_handle,
+                           double         factor)
+{
+  static GslDataHandleFuncs scale_handle_vtable = {
+    chain_handle_open,
+    scale_handle_read,
+    chain_handle_close,
+    NULL,
+    chain_handle_get_state_length,
+    scale_handle_destroy,
+  };
+  ScaledHandle *shandle;
+  gboolean success;
+  
+  g_return_val_if_fail (src_handle != NULL, NULL);
+  
+  shandle = sfi_new_struct0 (ScaledHandle, 1);
+  success = gsl_data_handle_common_init (&shandle->dhandle, NULL);
+  if (success)
+    {
+      shandle->dhandle.name = g_strconcat (src_handle->name, "// #scaled /", NULL);
+      shandle->dhandle.vtable = &scale_handle_vtable;
+      shandle->src_handle = gsl_data_handle_ref (src_handle);
+      shandle->factor = factor;
+    }
+  else
+    {
+      sfi_delete_struct (ScaledHandle, shandle);
+      return NULL;
+    }
+  return &shandle->dhandle;
+}
+
 /* --- cut handle --- */
 typedef struct {
   GslDataHandle     dhandle;
@@ -1395,6 +1488,11 @@ wave_format_bit_depth (const GslWaveFormatType format)
     case GSL_WAVE_FORMAT_UNSIGNED_16:
     case GSL_WAVE_FORMAT_SIGNED_16:
       return 16;
+    case GSL_WAVE_FORMAT_SIGNED_24:
+    case GSL_WAVE_FORMAT_SIGNED_24_PAD4:
+      return 24;
+    case GSL_WAVE_FORMAT_SIGNED_32:
+      return 32;
     case GSL_WAVE_FORMAT_FLOAT:
       return 32;
     default:
@@ -1506,7 +1604,7 @@ wave_handle_read (GslDataHandle *dhandle,
   
   switch (whandle->format)
     {
-      guint8 *u8; gint8 *s8; guint16 *u16; guint32 *u32;
+      guint8 *u8; gint8 *s8; guint16 *u16; guint32 *u32; gint32 *s32;
     case GSL_WAVE_FORMAT_UNSIGNED_8:
       u8 = buffer; u8 += n_values * 3;
       l = gsl_hfile_pread (whandle->hfile, byte_offset, n_values, u8);
@@ -1534,6 +1632,30 @@ wave_handle_read (GslDataHandle *dhandle,
       l >>= 1;
       gsl_conv_to_float (whandle->format, whandle->byte_order, u16, values, l);
       break;
+    case GSL_WAVE_FORMAT_SIGNED_24:
+      s8 = buffer; s8 += n_values * 1;
+      l = gsl_hfile_pread (whandle->hfile, byte_offset, n_values * 3, s8);
+      if (l < 3)
+	return l < 0 ? l : 0;
+      l /= 3;
+      gsl_conv_to_float (whandle->format, whandle->byte_order, s8, values, l);
+      break;
+    case GSL_WAVE_FORMAT_SIGNED_24_PAD4:
+      s32 = buffer;
+      l = gsl_hfile_pread (whandle->hfile, byte_offset, n_values * 4, s32);
+      if (l < 4)
+	return l < 0 ? l : 0;
+      l /= 4;
+      gsl_conv_to_float (whandle->format, whandle->byte_order, s32, values, l);
+      break;
+    case GSL_WAVE_FORMAT_SIGNED_32:
+      s32 = buffer;
+      l = gsl_hfile_pread (whandle->hfile, byte_offset, n_values * 4, s32);
+      if (l < 4)
+        return l < 0 ? l : 0;
+      l /= 4;
+      gsl_conv_to_float (whandle->format, whandle->byte_order, s32, values, l);
+      break;
     case GSL_WAVE_FORMAT_FLOAT:
       u32 = buffer;
       l = gsl_hfile_pread (whandle->hfile, byte_offset, n_values << 2, u32);
@@ -1626,15 +1748,18 @@ gsl_wave_format_to_string (GslWaveFormatType format)
 {
   switch (format)
     {
-    case GSL_WAVE_FORMAT_UNSIGNED_8:    return "unsigned-8";
-    case GSL_WAVE_FORMAT_SIGNED_8:      return "signed-8";
-    case GSL_WAVE_FORMAT_ALAW:          return "alaw";
-    case GSL_WAVE_FORMAT_ULAW:          return "ulaw";
-    case GSL_WAVE_FORMAT_UNSIGNED_12:   return "unsigned-12";
-    case GSL_WAVE_FORMAT_SIGNED_12:     return "signed-12";
-    case GSL_WAVE_FORMAT_UNSIGNED_16:   return "unsigned-16";
-    case GSL_WAVE_FORMAT_SIGNED_16:     return "signed-16";
-    case GSL_WAVE_FORMAT_FLOAT:         return "float";
+    case GSL_WAVE_FORMAT_UNSIGNED_8:      return "unsigned-8";
+    case GSL_WAVE_FORMAT_SIGNED_8:        return "signed-8";
+    case GSL_WAVE_FORMAT_ALAW:            return "alaw";
+    case GSL_WAVE_FORMAT_ULAW:            return "ulaw";
+    case GSL_WAVE_FORMAT_UNSIGNED_12:     return "unsigned-12";
+    case GSL_WAVE_FORMAT_SIGNED_12:       return "signed-12";
+    case GSL_WAVE_FORMAT_UNSIGNED_16:     return "unsigned-16";
+    case GSL_WAVE_FORMAT_SIGNED_16:       return "signed-16";
+    case GSL_WAVE_FORMAT_SIGNED_24:       return "signed-24";
+    case GSL_WAVE_FORMAT_SIGNED_24_PAD4:  return "signed-24-pad";
+    case GSL_WAVE_FORMAT_SIGNED_32:       return "signed-32";
+    case GSL_WAVE_FORMAT_FLOAT:           return "float";
     default:
       g_return_val_if_fail (format > GSL_WAVE_FORMAT_NONE && format < GSL_WAVE_FORMAT_LAST, NULL);
       return NULL;
@@ -1670,12 +1795,18 @@ gsl_wave_format_from_string (const gchar *string)
   string += 1;
   if (string[0] == '8')
     return is_unsigned ? GSL_WAVE_FORMAT_UNSIGNED_8 : GSL_WAVE_FORMAT_SIGNED_8;
-  if (string[0] != '1')
-    return GSL_WAVE_FORMAT_NONE;
-  string += 1;
-  if (string[0] == '2')
+  if (string[0] == '1' && string[1] == '2')
     return is_unsigned ? GSL_WAVE_FORMAT_UNSIGNED_12 : GSL_WAVE_FORMAT_SIGNED_12;
-  if (string[0] == '6')
+  if (string[0] == '1' && string[1] == '6')
     return is_unsigned ? GSL_WAVE_FORMAT_UNSIGNED_16 : GSL_WAVE_FORMAT_SIGNED_16;
+  if (string[0] == '3' && string[1] == '2' && !is_unsigned)
+    return GSL_WAVE_FORMAT_SIGNED_32;
+  if (string[0] == '2' && string[1] == '4' && !is_unsigned)
+    {
+      if (string[2] == '-' && string[3] == 'p' && string[4] == 'a' && string[5] == 'd')
+        return GSL_WAVE_FORMAT_SIGNED_24_PAD4;
+      else
+        return GSL_WAVE_FORMAT_SIGNED_24;
+    }
   return GSL_WAVE_FORMAT_NONE;
 }
