@@ -5,17 +5,15 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #ifndef __GSL_DATA_HANDLE_H__
 #define __GSL_DATA_HANDLE_H__
@@ -81,33 +79,37 @@ guint		  gsl_data_handle_n_channels	    (GslDataHandle	  *data_handle);
 guint		  gsl_data_handle_bit_depth	    (GslDataHandle	  *data_handle);
 gfloat		  gsl_data_handle_mix_freq	    (GslDataHandle	  *data_handle);
 gfloat		  gsl_data_handle_osc_freq	    (GslDataHandle	  *data_handle);
+gfloat            gsl_data_handle_volume            (GslDataHandle        *data_handle);
+gfloat            gsl_data_handle_fine_tune         (GslDataHandle        *data_handle);
 const gchar*	  gsl_data_handle_name		    (GslDataHandle	  *data_handle);
 int64		  gsl_data_handle_read		    (GslDataHandle	  *data_handle,
 						     int64		   value_offset,
 						     int64		   n_values,
 						     gfloat		  *values);
-int64		  gsl_data_handle_get_state_length  (GslDataHandle    *dhandle);
-GslDataHandle*    gsl_data_handle_get_source	    (GslDataHandle    *dhandle);
+int64		  gsl_data_handle_get_state_length  (GslDataHandle        *dhandle);
+GslDataHandle*    gsl_data_handle_get_source	    (GslDataHandle        *dhandle);
+GslDataHandle*	  gsl_data_handle_new_scale         (GslDataHandle	  *src_handle,
+                                                     double                factor);
 GslDataHandle*	  gsl_data_handle_new_cut	    (GslDataHandle	  *src_handle,
 						     int64		   cut_offset,
 						     int64		   n_cut_values);
 GslDataHandle*	  gsl_data_handle_new_crop	    (GslDataHandle	  *src_handle,
-						     int64  	   n_head_cut,
+						     int64  	           n_head_cut,
 						     int64		   n_tail_cut);
 GslDataHandle*	  gsl_data_handle_new_reverse	    (GslDataHandle	  *src_handle);
 GslDataHandle*	  gsl_data_handle_new_insert	    (GslDataHandle	  *src_handle,
-						     guint             pasted_bit_depth,
+						     guint                 pasted_bit_depth,
 						     int64		   insertion_offset,
 						     int64		   n_paste_values,
 						     const gfloat	  *paste_values,
-						     void            (*free) (gpointer values));
+						     void                (*free) (gpointer values));
 GslDataHandle*	  gsl_data_handle_new_mem	    (guint		   n_channels,
-						     guint             bit_depth,
-						     gfloat            mix_freq,
-						     gfloat            osc_freq,
+						     guint                 bit_depth,
+						     gfloat                mix_freq,
+						     gfloat                osc_freq,
 						     int64		   n_values,
 						     const gfloat	  *values,
-						     void            (*free) (gpointer values));
+						     void                (*free) (gpointer values));
 GslDataHandle*	  gsl_data_handle_new_dcached	    (GslDataCache	  *dcache);
 /* cheap and inefficient, testpurpose only */
 GslDataHandle*	  gsl_data_handle_new_looped	    (GslDataHandle	  *src_handle,
@@ -151,6 +153,9 @@ typedef enum    /*< skip >*/
   GSL_WAVE_FORMAT_SIGNED_12,
   GSL_WAVE_FORMAT_UNSIGNED_16,
   GSL_WAVE_FORMAT_SIGNED_16,
+  GSL_WAVE_FORMAT_SIGNED_24,
+  GSL_WAVE_FORMAT_SIGNED_24_PAD4,
+  GSL_WAVE_FORMAT_SIGNED_32,
   GSL_WAVE_FORMAT_FLOAT,
   GSL_WAVE_FORMAT_LAST
 } GslWaveFormatType;
