@@ -5,17 +5,15 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General 
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include <bse/bsemathsignal.h>
 #include <bse/bsemain.h>
@@ -23,11 +21,16 @@
 #include <sfi/sfitests.h>
 #include <bse/gsldatautils.h>
 #include <bse/bseblockutils.hh>
+#include <stdlib.h>
 #include <vector>
+#include <string>
+#include <map>
 
 using std::vector;
+using std::string;
 using std::max;
 using std::min;
+using std::map;
 
 static void
 read_through (GslDataHandle *handle)
@@ -103,7 +106,7 @@ check (const char           *up_down,
       for (int64 i = 0; i < rhandle->setup.n_values; i++)
 	{
 	  double resampled = gsl_data_handle_peek_value (rhandle, i, &peek_buffer);
-	  worst_diff = max (resampled - expected[i], worst_diff);
+	  worst_diff = max (fabs (resampled - expected[i]), worst_diff);
 	}
       worst_diff_db = bse_db_from_factor (worst_diff, -200);
       TPRINT ("linear(%dst read) read worst_diff = %f (%f dB)\n", repeat, worst_diff, worst_diff_db);
@@ -112,7 +115,7 @@ check (const char           *up_down,
 
   /* test seeking */
   worst_diff = 0.0;
-  const uint count = sfi_init_settings().test_slow ? 3000 : 100;
+  const uint count = sfi_init_settings().test_slow ? 300 : 100;
   for (uint j = 0; j < count; j++)
     {
       int64 start = rand() % rhandle->setup.n_values;
@@ -122,7 +125,7 @@ check (const char           *up_down,
       for (int64 i = start; i < std::min (start + len, rhandle->setup.n_values); i++)
 	{
 	  double resampled = gsl_data_handle_peek_value (rhandle, i, &peek_buffer);
-	  worst_diff = max (resampled - expected[i], worst_diff);
+	  worst_diff = max (fabs (resampled - expected[i]), worst_diff);
 	}
     }
   worst_diff_db = bse_db_from_factor (worst_diff, -200);
@@ -174,20 +177,38 @@ generate_test_signal (vector<Sample> &signal,
                       const double    frequency1,
 		      const double    frequency2 = -1)
 {
-  signal.clear();
-  for (size_t i = 0; i < signal_length; i++)
+  static map<size_t, vector<float> > window_cache;
+  vector<float>& cached_window = window_cache[signal_length];
+  if (cached_window.empty())
     {
-      double wpos = (i * 2 - double (signal_length)) / signal_length;
+      cached_window.resize (signal_length);
 
-      double phase1 = i * 2 * M_PI * frequency1 / sample_rate;
-      signal.push_back (sin (phase1) * bse_window_blackman (wpos));
-
-      if (frequency2 > 0)   /* stereo */
-	{
-	  double phase2 = i * 2 * M_PI * frequency2 / sample_rate;
-	  signal.push_back (sin (phase2) * bse_window_blackman (wpos));
-	}
+      for (size_t i = 0; i < signal_length; i++)
+        {
+          double wpos = (i * 2 - double (signal_length)) / signal_length;
+          cached_window[i] = bse_window_blackman (wpos);
+        }
     }
+
+  string signal_cache_key = Birnet::string_printf ("%zd/%.1f/%.1f/%.1f", signal_length, sample_rate, frequency1, frequency2);
+  static map<string, vector<Sample> > signal_cache;
+  vector<Sample>& cached_signal = signal_cache[signal_cache_key];
+
+  if (cached_signal.empty())
+    {
+      for (size_t i = 0; i < signal_length; i++)
+        {
+          double phase1 = i * 2 * M_PI * frequency1 / sample_rate;
+          cached_signal.push_back (sin (phase1) * cached_window[i]);
+
+          if (frequency2 > 0)   /* stereo */
+            {
+              double phase2 = i * 2 * M_PI * frequency2 / sample_rate;
+              cached_signal.push_back (sin (phase2) * cached_window[i]);
+            }
+        }
+    }
+  signal = cached_signal;
 }
 
 static void
@@ -211,7 +232,7 @@ run_tests (const char *run_type)
 
   for (int p = 0; params[p].bits; p++)
     {
-      const int LEN = 44100 * 4;
+      const int LEN = 44100 / 2;  /* 500ms test signal */
       vector<float> input;
       vector<double> expected;
 
