@@ -1,21 +1,19 @@
-/* BSE - Bedevilled Sound Engine
+/* BSE - Better Sound Engine
  * Copyright (C) 2006 Tim Janik
  * Copyright (C) 2006 Stefan Westerfeld
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include <bse/bse.h>
 #include <bse/bseieee754.h>
@@ -23,6 +21,9 @@
 //#define TEST_VERBOSE
 #include <birnet/birnettests.h>
 #include <stdio.h>
+#ifdef __SSE__
+#include <xmmintrin.h>
+#endif
 
 #if 1
 inline float  test1f (float v) { return v;     }
@@ -212,21 +213,45 @@ benchmark_subnormal_eliminations ()
   treport_minimized ("Subnormals-bse-flush",    test6_time, TUNIT_SECOND);
 }
 
+bool
+check_denormals_are_zero()
+{
+#if defined (__x86_64__) && (FLT_EVAL_METHOD == 0) && defined (__SSE__)
+  if (_MM_GET_FLUSH_ZERO_MODE() == _MM_FLUSH_ZERO_ON)
+    {
+      const int MM_DENORMALS_ARE_ZERO = 0x40;
+
+      if (_mm_getcsr() & MM_DENORMALS_ARE_ZERO)
+        {
+          return true;
+        }
+    }
+#endif
+
+  return false;
+}
+
 int
 main (int   argc,
       char *argv[])
 {
   bse_init_test (&argc, &argv, NULL);
 
-  test_correct_subnormal_elimination<test2f> ("zap");
-  test_correct_subnormal_elimination<test3f> ("inlined-cond");
-  test_correct_subnormal_elimination<test4f> ("if-cond");
-  test_correct_subnormal_elimination<test5f> ("arithmetic");
+  g_printerr ("Checking if your processor is in 'denormals are zero' (DAZ) mode... ");
+  bool daz_mode = check_denormals_are_zero();
+  g_printerr (daz_mode ? "yes - skipping subnormal elimination tests.\n" : "no.\n");
+  if (!daz_mode)
+    {
+      test_correct_subnormal_elimination<test2f> ("zap");
+      test_correct_subnormal_elimination<test3f> ("inlined-cond");
+      test_correct_subnormal_elimination<test4f> ("if-cond");
+      test_correct_subnormal_elimination<test5f> ("arithmetic");
 
-  test_correct_subnormal_elimination<test2d> ("zap-double");
-  test_correct_subnormal_elimination<test3d> ("inlined-cond-double");
-  test_correct_subnormal_elimination<test4d> ("if-cond-double");
-  test_correct_subnormal_elimination<test5d> ("arithmetic-double");
+      test_correct_subnormal_elimination<test2d> ("zap-double");
+      test_correct_subnormal_elimination<test3d> ("inlined-cond-double");
+      test_correct_subnormal_elimination<test4d> ("if-cond-double");
+      test_correct_subnormal_elimination<test5d> ("arithmetic-double");
+    }
 
   if (sfi_init_settings().test_perf)
     benchmark_subnormal_eliminations();
