@@ -1,39 +1,32 @@
 /* DavXtalStrings - DAV Physical Modelling String Synthesizer
  * Copyright (c) 2000 David A. Bartold, 2001 Tim Janik
+ * Copyright (c) 2007 Stefan Westerfeld
  *
- * Generate a string pluck sound using a modified Karplus-Strong algorithm
- * and then use Brensenham's algorithm to correct the frequency.
- *
- * This software uses technology under patent US 4,649,783, which is
- * set to expire in May of 2004.  In the meantime, a non-patented
- * alternative to this module is in the works.
- *
- ***********************************************************************
- *
- * Any commercial use of this module requires a license from
- * Stanford University until 2004.
- *
- ***********************************************************************
- *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
+ */
+
+/* Generate a string pluck sound using a modified Karplus-Strong algorithm
+ * and then use Brensenham's algorithm to correct the frequency.
+ *
+ * This software uses technology under patent US 4,649,783, which has
+ * expired in May of 2004.
  */
 #include "davxtalstrings.h"
 
 #include <bse/bseengine.h>
 #include <bse/bsemathsignal.h>
+#include <bse/bsemain.h>
 
 #include <string.h>
 
@@ -301,6 +294,44 @@ calc_factor (gfloat freq,
   return pow (0.5, 1.0 / (freq * t));
 }
 
+/* mini random number generator (adapted from rapicorn), to generate deterministic
+ * sequence of booleans when --bse-disable-randomization was used
+ */
+typedef struct 
+{
+  gboolean allow_randomization;
+  guint32  seed;
+  guint32  mask;
+} DavRand;
+
+static void 
+dav_rand_setup (DavRand *rand,
+                gboolean allow_randomization)
+{
+  rand->seed = 2147483563;
+  rand->mask = 0;
+  rand->allow_randomization = allow_randomization;
+}
+
+static gboolean
+dav_rand_bool (DavRand *rand)
+{
+  if (rand->allow_randomization)
+    {
+      return bse_rand_bool();
+    }
+  else
+    {
+      rand->mask <<= 1;
+      if (!rand->mask)
+        {
+          rand->mask = 1;
+          rand->seed = 1664525 * rand->seed + 1013904223;
+        }
+      return ((rand->seed & rand->mask) == 0);
+    }
+}
+
 /* the GSL engine module that generates the signal, there may be many
  * modules per DavXtalStrings object
  */
@@ -329,7 +360,7 @@ xmod_trigger (XtalStringsModule *xmod,
    */
   gdouble trigger_freq = untransposed_trigger_freq;
   trigger_freq *= xmod->tparams.transpose_factor;
-  trigger_freq *= bse_cent_factor (xmod->tparams.fine_tune);
+  trigger_freq *= bse_cent_tune_fast (xmod->tparams.fine_tune);
   trigger_freq = CLAMP (trigger_freq, 27.5, 4000.0);
   xmod->last_transposed_trigger_freq = trigger_freq;
   
@@ -352,9 +383,11 @@ xmod_trigger (XtalStringsModule *xmod,
     xmod->string[i] = pow (xmod->string[i], xmod->tparams.snap_factor * 10.0 + 1.0);
   
   /* Add static to displacements. */
+  DavRand rand;
+  dav_rand_setup (&rand, bse_main_args->allow_randomization);
   for (i = 0; i < xmod->size; i++)
     xmod->string[i] = (xmod->string[i] * (1.0F - xmod->tparams.metallic_factor) +
-		       (bse_rand_bool () ? -1.0F : 1.0F) * xmod->tparams.metallic_factor);
+		       (dav_rand_bool (&rand) ? -1.0F : 1.0F) * xmod->tparams.metallic_factor);
   /* Set velocity. */
   for (i = 0; i < xmod->size; i++)
     xmod->string[i] *= xmod->tparams.trigger_vel;
