@@ -4,17 +4,15 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #ifndef __SFI_TYPES_H__
 #define __SFI_TYPES_H__
@@ -29,10 +27,10 @@ typedef bool			SfiBool;
 typedef gint			SfiInt;
 #define	SFI_MAXINT		(+2147483647)
 #define	SFI_MININT		(-SFI_MAXINT - 1)
-typedef gint64			SfiNum;
+typedef int64			SfiNum;
 #define	SFI_MAXNUM		((SfiNum) +9223372036854775807LL)
 #define	SFI_MINNUM		(-SFI_MAXNUM - 1)
-typedef gint64			SfiTime;
+typedef int64			SfiTime;
 typedef SfiInt			SfiNote;
 typedef double			SfiReal;
 #define SFI_MINREAL		(2.2250738585072014e-308)	/* IEEE754 double */
