@@ -4,17 +4,15 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include <bse/bsemain.h>
 #include <bse/bseengine.h>
@@ -24,6 +22,8 @@
 #include <bse/gslfft.h>
 #include <bse/gslfilter.h>
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
 #include <errno.h>
 #include <assert.h>
 #include "topconfig.h"
@@ -48,10 +48,14 @@ struct Options {
   guint               channel;
   bool                cut_zeros_head;
   bool                cut_zeros_tail;
+  bool                verbose;
   gdouble             silence_threshold;
   gdouble             base_freq_hint;
   gdouble             focus_center;
   gdouble             focus_width;
+  guint               join_spectrum_slices;
+  guint               timing_window_stepping_ms;
+  guint               timing_window_size_ms;
 
   FILE               *output_file;
 
@@ -59,20 +63,21 @@ struct Options {
   void parse (int *argc_p, char **argv_p[]);
   static void print_usage ();
   void validate_percent (const string& option, gdouble value);
+  void validate_int (const string& option, int value, int vmin, int vmax);
 } options;
 
 class Signal
 {
-  mutable GslDataPeekBuffer peek_buffer;
-  GslDataHandle	 *data_handle;
-  guint		  signal_n_channels;
-  GslLong	  signal_length;
-  GslLong         signal_offset;
+  vector<float>   m_samples;
+  GslDataHandle	 *m_data_handle;
+  guint		  m_n_channels;
+  GslLong	  m_length;
+  GslLong         m_offset;
 
   /* check if the first sample is silent on all channels */
   bool head_is_silent()
   {
-    for (guint i = 0; i < signal_n_channels; i++)
+    for (guint i = 0; i < m_n_channels; i++)
       if (fabs ((*this)[i]) > options.silence_threshold)
 	return false;
 
@@ -82,39 +87,50 @@ class Signal
   /* check if the last sample is silent on all channels */
   bool tail_is_silent()
   {
-    for (guint i = 0; i < signal_n_channels; i++)
-      if (fabs ((*this)[signal_length - signal_n_channels + i]) > options.silence_threshold)
+    for (guint i = 0; i < m_n_channels; i++)
+      if (fabs ((*this)[m_length - m_n_channels + i]) > options.silence_threshold)
 	return false;
 
     return true;
   }
 
 public:
-  Signal (GslDataHandle *data_handle)
-    : data_handle (data_handle)
+  Signal (GslDataHandle *data_handle) :
+    m_data_handle (data_handle)
   {
-    signal_n_channels = gsl_data_handle_n_channels (data_handle);
-    signal_length = gsl_data_handle_length (data_handle);
-    signal_offset = 0;
+    m_n_channels = gsl_data_handle_n_channels (data_handle);
+    m_length = gsl_data_handle_length (data_handle);
+    m_offset = 0;
 
-    memset (&peek_buffer, 0, sizeof (peek_buffer));
-    peek_buffer.dir = 1; /* incremental direction */;
+    m_samples.resize (m_length);
+    size_t have_samples = 0;
+    while (have_samples < m_length)
+      {
+        int64 r = gsl_data_handle_read (data_handle, have_samples, MIN (m_length - have_samples, 4096 * m_n_channels),
+                                        &m_samples[have_samples]);
+        if (r < 0)
+          {
+            g_printerr ("error reading sample data\n");
+            exit (1);
+          }
+        have_samples += r;
+      }
 
     if (options.cut_zeros_head)
       {
 	/* cut_zeros head */
-	while (head_is_silent() && signal_length > (GslLong) signal_n_channels)
+	while (head_is_silent() && m_length > (GslLong) m_n_channels)
 	  {
-	    signal_offset += signal_n_channels;
-	    signal_length -= signal_n_channels;
+	    m_offset += m_n_channels;
+	    m_length -= m_n_channels;
 	  }
       }
     if (options.cut_zeros_tail)
       {
 	/* cut_zeros tail */
-	while (tail_is_silent() && signal_length > (GslLong) signal_n_channels)
+	while (tail_is_silent() && m_length > (GslLong) m_n_channels)
 	  {
-	    signal_length -= signal_n_channels;
+	    m_length -= m_n_channels;
 	  }
       }
 
@@ -129,34 +145,34 @@ public:
     double start = options.focus_center - (options.focus_width / 2.0);
     double end = options.focus_center + (options.focus_width / 2.0);
 
-    GslLong istart = GslLong (start / 100.0 * signal_length + 0.5);
-    GslLong iend = GslLong (end / 100.0 * signal_length + 0.5);
+    GslLong istart = GslLong (start / 100.0 * m_length + 0.5);
+    GslLong iend = GslLong (end / 100.0 * m_length + 0.5);
 
-    istart -= istart % signal_n_channels;
-    iend -= iend % signal_n_channels;
+    istart -= istart % m_n_channels;
+    iend -= iend % m_n_channels;
 
-    signal_offset += istart;
-    signal_length = iend - istart;
+    m_offset += istart;
+    m_length = iend - istart;
   }
 
   GslLong length() const
   {
-    return signal_length;
+    return m_length;
   }
 
   guint n_channels() const
   {
-    return signal_n_channels;
+    return m_n_channels;
   }
 
   double operator[] (GslLong k) const
   {
-    return gsl_data_handle_peek_value (data_handle, k + signal_offset, &peek_buffer);
+    return m_samples[k + m_offset];
   }
   
   double mix_freq() const
   {
-    return gsl_data_handle_mix_freq (data_handle);
+    return gsl_data_handle_mix_freq (m_data_handle);
   }
 
   double time_ms (GslLong k) const
@@ -177,27 +193,34 @@ struct Feature
   bool        extract_feature;      /* did the user enable this feature with --feature? */
 
   string
-  double_to_string (double value, bool align = false) const
+  double_to_string (double value,
+                    bool   align = false) const
   {
     gchar numbuf[G_ASCII_DTOSTR_BUF_SIZE + 1] = "";
     g_ascii_formatd (numbuf, G_ASCII_DTOSTR_BUF_SIZE, align ? "%-15.9g" : "%.9g", value);
     return numbuf;
   }
 
-  void print_value (const string& value_name, double data) const
+  void
+  print_value (const string &value_name,
+               double        data) const
   {
     fprintf (options.output_file, "%s = %s;\n", value_name.c_str(), double_to_string (data).c_str());
   }
 
-  void print_vector (const string& vector_name, const vector<double>& data) const
+  void
+  print_vector (const string         &vector_name,
+                const vector<double> &data) const
   {
-    fprintf (options.output_file, "%s[%ld] = {", vector_name.c_str(), data.size());
+    fprintf (options.output_file, "%s[%zd] = {", vector_name.c_str(), data.size());
     for (vector<double>::const_iterator di = data.begin(); di != data.end(); di++)
       fprintf (options.output_file, " %s", double_to_string (*di, true).c_str());
     fprintf (options.output_file, " };\n");
   }
 
-  void print_matrix (const string& matrix_name, const vector< vector<double> >& matrix) const
+  void
+  print_matrix (const string                   &matrix_name,
+                const vector< vector<double> > &matrix) const
   {
     /* for a m x n matrix, we write
      * 
@@ -209,7 +232,7 @@ struct Feature
      *   { x_m1 x_m2 ... x_mn }
      * };
      */
-    fprintf (options.output_file, "%s[%ld,%ld] = {\n",
+    fprintf (options.output_file, "%s[%zd,%zd] = {\n",
 	     matrix_name.c_str(), matrix.size(), matrix.size() ? matrix[0].size() : 0);
 
     for (vector< vector<double> >::const_iterator mi = matrix.begin(); mi != matrix.end(); mi++)
@@ -224,12 +247,15 @@ struct Feature
     fprintf (options.output_file, "};\n");
   }
 
-  Feature (const char *option, const char *description)
-    : option (option), description (description), extract_feature (false)
+  Feature (const char *option,
+           const char *description) :
+    option (option),
+    description (description),
+    extract_feature (false)
   {
   }
 
-  virtual void compute (const Signal& signal) = 0;
+  virtual void compute (const Signal &signal) = 0;
   virtual void print_results() const = 0;
   virtual ~Feature()
   {
@@ -239,11 +265,13 @@ struct Feature
 struct StartTimeFeature : public Feature
 {
   double start_time;
-  StartTimeFeature() : Feature ("--start-time", "signal start time in ms (first non-zero sample)")
+  StartTimeFeature() :
+    Feature ("--start-time", "signal start time in ms (first non-zero sample)")
   {
     start_time = -1;
   }
-  void compute (const Signal& signal)
+  void
+  compute (const Signal &signal)
   {
     for (GslLong l = options.channel; l < signal.length(); l += signal.n_channels())
       {
@@ -254,7 +282,8 @@ struct StartTimeFeature : public Feature
 	  }
       }
   }
-  void print_results() const
+  void
+  print_results() const
   {
     print_value ("start_time", start_time);
   }
@@ -267,7 +296,7 @@ struct EndTimeFeature : public Feature
   {
     end_time = -1;
   }
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     for (GslLong l = options.channel; l < signal.length(); l += signal.n_channels())
       {
@@ -284,21 +313,34 @@ struct EndTimeFeature : public Feature
 struct SpectrumFeature : public Feature
 {
   vector< vector<double> > spectrum;
+  vector< vector<double> > joined_spectrum;
+  vector< double >         window;
 
-  SpectrumFeature() : Feature ("--spectrum", "generate 30ms spaced frequency spectrums")
+  SpectrumFeature() :
+    Feature ("--spectrum", "generate 30ms sliced frequency spectrums")
   {
   }
 
-  vector<double>
-  build_frequency_vector (GslLong size,
-			  double *samples)
+  void
+  init_window (size_t size)
   {
+    window.resize (size);
+
+    for (size_t i = 0; i < size; i++)
+      window[i] = bse_window_blackman (2.0 * i / size - 1.0); /* the bse blackman window is defined in range [-1, 1] */
+  }
+
+  vector<double>
+  build_frequency_vector (double *samples)
+  {
+    const size_t size = window.size();
+    assert (size > 0);
+
     vector<double> fvector;
     double in[size], c[size + 2], *im;
-    gint i;
 
-    for (i = 0; i < size; i++)
-      in[i] = bse_window_blackman (2.0 * i / size - 1.0) * samples[i]; /* the bse blackman window is defined in range [-1, 1] */
+    for (size_t i = 0; i < size; i++)
+      in[i] = window[i] * samples[i];
 
     gsl_power2_fftar (size, in, c);
     c[size] = c[1];
@@ -306,7 +348,7 @@ struct SpectrumFeature : public Feature
     c[1] = 0;
     im = c + 1;
 
-    for (i = 0; i <= size >> 1; i++)
+    for (size_t i = 0; i <= size >> 1; i++)
       {
 	double abs = sqrt (c[i << 1] * c[i << 1] + im[i << 1] * im[i << 1]);
 	/* FIXME: is this the correct normalization? */
@@ -316,10 +358,10 @@ struct SpectrumFeature : public Feature
   }
 
   vector<double>
-  collapse_frequency_vector (const vector<double>& fvector,
-			     double mix_freq,
-			     double first_freq,
-			     double factor)
+  collapse_frequency_vector (const vector<double> &fvector,
+			     double                mix_freq,
+			     double                first_freq,
+			     double                factor)
   {
     vector<double> result;
     double value = 0;
@@ -347,12 +389,37 @@ struct SpectrumFeature : public Feature
     return result;
   }
 
+  vector<double>
+  static join_slices (vector< vector<double> >::const_iterator start,
+		      vector< vector<double> >::const_iterator end,
+		      double                                   normalize)
+  {
+    const vector < double > empty_return; // this can't be inlined in g_return* due to a bug in g++-3.3
+    g_return_val_if_fail (end - start > 0, empty_return);
+
+    vector<double> result (start->size());
+
+    for (vector< vector<double> >::const_iterator spect_it = start; spect_it != end; spect_it++)
+      {
+	g_return_val_if_fail (spect_it->size() == result.size(), result);
+
+	for (size_t i = 0; i < result.size(); i++)
+	  result[i] += (*spect_it)[i];
+      }
+    for (size_t i = 0; i < result.size(); i++)
+      result[i] /= normalize;
+
+    return result;
+  }
+
   void
-  compute (const Signal& signal)
+  compute (const Signal &signal)
   {
     if (spectrum.size()) /* don't compute the same feature twice */
       return;
 
+    init_window (4096);
+
     double file_size_ms = signal.time_ms (signal.length());
 
     for (double offset_ms = 0; offset_ms < file_size_ms; offset_ms += 30) /* extract a feature vector every 30 ms */
@@ -375,30 +442,54 @@ struct SpectrumFeature : public Feature
 
 	if (!skip)
 	  {
-	    vector<double> fvector = build_frequency_vector (4096, samples);
+	    vector<double> fvector = build_frequency_vector (samples);
 	    spectrum.push_back (collapse_frequency_vector (fvector, signal.mix_freq(), 50, 1.6));
 	  }
       }
+
+    if (options.join_spectrum_slices > 1)
+      {
+	typedef vector< vector<double> >::const_iterator SpectrumConstIterator;
+	const guint jslices = options.join_spectrum_slices; 
+
+	/* for N-fold joining, we "truncate" the spectrum so that we only
+	 * have complete sets of N 30ms spectrum buckets to join
+	 */
+	for (size_t i = 0; i + jslices <= spectrum.size(); i += jslices)
+	  {
+	    SpectrumConstIterator jstart_it = spectrum.begin();
+	    SpectrumConstIterator jend_it = spectrum.begin() + jslices;
+	    joined_spectrum.push_back (join_slices (jstart_it, jend_it, jslices));
+	  }
+      }
   }
 
   void print_results() const
   {
-    print_matrix ("spectrum", spectrum);
+    if (options.join_spectrum_slices > 1)
+      {
+	fprintf (options.output_file,
+	         "# this spectrum was computed with --join-spectrum-slices=%d\n",
+	         options.join_spectrum_slices);
+	print_matrix ("spectrum", joined_spectrum);
+      }
+    else
+      print_matrix ("spectrum", spectrum);
   }
 };
 
 struct AvgSpectrumFeature : public Feature
 {
   SpectrumFeature *spectrum_feature;
-  vector<double> avg_spectrum;
+  vector<double>   avg_spectrum;
 
-  AvgSpectrumFeature (SpectrumFeature *spectrum_feature)
-    : Feature ("--avg-spectrum", "average frequency spectrum"),
-      spectrum_feature (spectrum_feature)
+  AvgSpectrumFeature (SpectrumFeature *spectrum_feature) :
+    Feature ("--avg-spectrum", "average frequency spectrum"),
+    spectrum_feature (spectrum_feature)
   {
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     /*
      * dependancy: we need the spectrum to compute the average spectrum
@@ -427,7 +518,7 @@ struct AvgEnergyFeature : public Feature
     avg_energy = 0;
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     GslLong avg_energy_count = 0;
     for (GslLong l = options.channel; l < signal.length(); l += signal.n_channels())
@@ -455,13 +546,14 @@ struct MinMaxPeakFeature : public Feature
   double min_peak;
   double max_peak;
 
-  MinMaxPeakFeature() : Feature ("--min-max-peak", "minimum and maximum signal peak")
+  MinMaxPeakFeature() :
+    Feature ("--min-max-peak", "minimum and maximum signal peak")
   {
     min_peak = 0;
     max_peak = 0;
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     for (GslLong l = options.channel; l < signal.length(); l += signal.n_channels())
       {
@@ -477,6 +569,36 @@ struct MinMaxPeakFeature : public Feature
   }
 };
 
+struct DCOffsetFeature : public Feature
+{
+  double dc_offset;
+
+  DCOffsetFeature() :
+    Feature ("--dc-offset-db", "computes the DC offset in dB")
+  {
+    dc_offset = 0;
+  }
+
+  void compute (const Signal &signal)
+  {
+    double dc_offset_div = 0.0;
+
+    for (GslLong l = options.channel; l < signal.length(); l += signal.n_channels())
+      {
+        dc_offset += signal[l];
+        dc_offset_div += 1.0;
+      }
+
+    if (dc_offset_div > 0.5)
+      dc_offset /= dc_offset_div;
+  }
+
+  void print_results() const
+  {
+    print_value ("dc_offset_db", bse_db_from_factor (dc_offset, -200));
+  }
+};
+
 struct RawSignalFeature : public Feature
 {
   vector<double> raw_signal;
@@ -485,7 +607,7 @@ struct RawSignalFeature : public Feature
   {
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     for (GslLong l = options.channel; l < signal.length(); l += signal.n_channels())
       raw_signal.push_back (signal[l]);
@@ -498,7 +620,7 @@ struct RawSignalFeature : public Feature
      * functions (because then gnuplot couldn't parse it any more).
      */
     for (guint i = 0; i < raw_signal.size(); i++)
-      fprintf (options.output_file, "%f\n", raw_signal[i]);
+      fprintf (options.output_file, "%s\n", double_to_string (raw_signal[i]).c_str());
   }
 };
 
@@ -507,7 +629,7 @@ struct ComplexSignalFeature : public Feature
   static const int HSIZE = 256;
 
   vector< std::complex<double> > complex_signal;
-  double hilbert[2*HSIZE+1];
+  double                         hilbert[2*HSIZE+1];
 
   /*
    * Evaluates the FIR frequency response of the hilbert filter.
@@ -541,7 +663,8 @@ struct ComplexSignalFeature : public Feature
     return blackman_window ((x + 1.0) / 2.0);
   }
 
-  ComplexSignalFeature() : Feature ("--complex-signal", "extract complex signal (hilbert filtered)")
+  ComplexSignalFeature() :
+    Feature ("--complex-signal", "extract complex signal (hilbert filtered)")
   {
     /* compute hilbert fir coefficients */
     for (int i = 0; i <= HSIZE; i++)
@@ -564,7 +687,7 @@ struct ComplexSignalFeature : public Feature
       }
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     if (complex_signal.size()) /* already finished? */
       return;
@@ -602,7 +725,8 @@ struct ComplexSignalFeature : public Feature
      * functions (because then gnuplot couldn't parse it any more).
      */
     for (guint i = 0; i < complex_signal.size(); i++)
-      fprintf (options.output_file, "%f %f\n", complex_signal[i].real(), complex_signal[i].imag());
+      fprintf (options.output_file, "%s %s\n", double_to_string (complex_signal[i].real()).c_str(),
+                                               double_to_string (complex_signal[i].imag()).c_str());
   }
 };
 
@@ -615,9 +739,9 @@ struct BaseFreqFeature : public Feature
   double base_freq_smear;
   double base_freq_wobble;
 
-  BaseFreqFeature (ComplexSignalFeature *complex_signal_feature)
-    : Feature ("--base-freq", "try to detect pitch of a signal"),
-      complex_signal_feature (complex_signal_feature)
+  BaseFreqFeature (ComplexSignalFeature *complex_signal_feature) :
+    Feature ("--base-freq", "try to detect pitch of a signal"),
+    complex_signal_feature (complex_signal_feature)
   {
     base_freq = 0;
     base_freq_smear = 0;
@@ -625,7 +749,7 @@ struct BaseFreqFeature : public Feature
   }
 
   void
-  compute (const Signal& signal)
+  compute (const Signal &signal)
   {
     if (freq.size()) /* already finished? */
       return;
@@ -725,7 +849,7 @@ struct BaseFreqFeature : public Feature
   }
 
   void
-  compute_smear_and_wobble (const Signal& signal)
+  compute_smear_and_wobble (const Signal &signal)
   {
     const int window_size = int (signal.mix_freq() / base_freq + 0.5);
     const int window_step = max (window_size / 3, 30);
@@ -782,9 +906,9 @@ struct BaseFreqSmear : public Feature
 {
   BaseFreqFeature *base_freq_feature;
 
-  BaseFreqSmear (BaseFreqFeature *base_freq_feature)
-    : Feature ("--base-freq-smear", "inaccuracy of pitch detection"),
-      base_freq_feature (base_freq_feature)
+  BaseFreqSmear (BaseFreqFeature *base_freq_feature) :
+    Feature ("--base-freq-smear", "inaccuracy of pitch detection"),
+    base_freq_feature (base_freq_feature)
   {
   }
 
@@ -812,7 +936,7 @@ struct BaseFreqWobble : public Feature
   {
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     /*
      * dependancy: we need the base frequency feature to compute the base frequency smear
@@ -844,7 +968,7 @@ struct VolumeFeature : public Feature
     volume_wobble = 0;
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     if (vol.size()) /* already finished? */
       return;
@@ -871,7 +995,7 @@ struct VolumeFeature : public Feature
     compute_smear_and_wobble (signal);
   }
 
-  void compute_smear_and_wobble (const Signal& signal)
+  void compute_smear_and_wobble (const Signal &signal)
   {
     const double window_size_ms = 30; /* window size in milliseconds */
     const int window_size = int (signal.mix_freq() * window_size_ms / 1000.0 + 0.5);
@@ -924,13 +1048,13 @@ struct VolumeSmear : public Feature
 {
   VolumeFeature *volume_feature;
 
-  VolumeSmear (VolumeFeature *volume_feature)
-    : Feature ("--volume-smear", "variation of signal volume"),
-      volume_feature (volume_feature)
+  VolumeSmear (VolumeFeature *volume_feature) :
+    Feature ("--volume-smear", "variation of signal volume"),
+    volume_feature (volume_feature)
   {
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     // dependancy: we need the volume feature to compute the volume smear
     volume_feature->compute (signal);
@@ -947,13 +1071,13 @@ struct VolumeWobble : public Feature
   VolumeFeature *volume_feature;
 
 
-  VolumeWobble (VolumeFeature *volume_feature)
-    : Feature ("--volume-wobble", "rate of changes in signal volume over time"),
-      volume_feature (volume_feature)
+  VolumeWobble (VolumeFeature *volume_feature) :
+    Feature ("--volume-wobble", "rate of changes in signal volume over time"),
+    volume_feature (volume_feature)
   {
   }
 
-  void compute (const Signal& signal)
+  void compute (const Signal &signal)
   {
     // dependancy: we need the volume feature to compute the volume wobble
     volume_feature->compute (signal);
@@ -965,22 +1089,194 @@ struct VolumeWobble : public Feature
   }
 };
 
+struct TimingSlices
+{
+  enum SpectralFluxType
+  {
+    SPECTRAL_FLUX_POSITIVE,
+    SPECTRAL_FLUX_NEGATIVE
+  };
+  vector< vector<double> > slices;
 
-Options::Options ()
+  vector<double>
+  build_frequency_vector (GslLong size,
+			  double *samples)
+  {
+    vector<double> fvector;
+    double in[size], c[size + 2], *im;
+    gint i;
+
+    for (i = 0; i < size; i++)
+      in[i] = bse_window_blackman (2.0 * i / size - 1.0) * samples[i]; /* the bse blackman window is defined in range [-1, 1] */
+
+    gsl_power2_fftar (size, in, c);
+    c[size] = c[1];
+    c[size + 1] = 0;
+    c[1] = 0;
+    im = c + 1;
+
+    for (i = 0; i <= size >> 1; i++)
+      {
+	double abs = sqrt (c[i << 1] * c[i << 1] + im[i << 1] * im[i << 1]);
+	/* FIXME: is this the correct normalization? */
+	fvector.push_back (abs / size);
+      }
+    return fvector;
+  }
+
+  void
+  compute (const Signal& signal)
+  {
+    if (slices.size()) /* don't compute the same feature twice */
+      return;
+
+    double file_size_ms = signal.time_ms (signal.length());
+    uint fft_size_samples = 2;
+
+    while (fft_size_samples / signal.mix_freq() * 1000 < options.timing_window_size_ms)
+      fft_size_samples *= 2;
+
+    if (options.verbose)
+      {
+	g_printerr ("timing window (for attack and release detection):\n");
+	g_printerr ("  * size         %5.2f ms    %6u samples\n",
+	  fft_size_samples / signal.mix_freq() * 1000,
+	  fft_size_samples);
+	g_printerr ("  * stepping     %5.2f ms    %6u samples\n",
+	  float (options.timing_window_stepping_ms),
+	  uint (options.timing_window_stepping_ms * signal.mix_freq() / 1000));
+      }
+
+    for (double offset_ms = 0; offset_ms < file_size_ms; offset_ms += options.timing_window_stepping_ms)
+      {
+	GslLong extract_frame = GslLong (offset_ms / file_size_ms * signal.length() / signal.n_channels());
+
+	double samples[fft_size_samples];
+	bool skip = false;
+	GslLong k = extract_frame * signal.n_channels() + options.channel;
+
+	for (uint j = 0; j < fft_size_samples; j++)
+	  {
+	    if (k < signal.length())
+	      samples[j] = signal[k];
+	    else
+	      skip = true; /* alternative implementation: fill up with zeros;
+			      however this results in click features being extracted at eof */
+	    k += signal.n_channels();
+	  }
+
+	if (!skip)
+	  slices.push_back (build_frequency_vector (fft_size_samples, samples));
+      }
+  }
+
+  int
+  n_slices()
+  {
+    return slices.size();
+  }
+
+  double
+  spectral_flux (int             slice1,
+                 int             slice2,
+		 SpectralFluxType sf_type)
+  {
+    /* make s1 and s2 point at the desired slices, or, if they are out of range,
+     * at a sufficiently large null slice (where sufficiently large may be 0,
+     * if both slices were out of the range for which features have been extracted) */
+    vector<double> null_slice;
+    vector<double>& s1 = (slice1 >= 0 && slice1 < slices.size()) ? slices[slice1] : null_slice;
+    vector<double>& s2 = (slice2 >= 0 && slice2 < slices.size()) ? slices[slice2] : null_slice;
+    null_slice.resize (max (s1.size(), s2.size()));
+
+    double sf = 0;
+    for (size_t i = 0; i < s1.size(); i++)
+      {
+	if ((s1[i] < s2[i]) == (sf_type == SPECTRAL_FLUX_POSITIVE))
+	  sf += fabs (s1[i] - s2[i]);
+      }
+    return sf;
+  }
+};
+
+struct AttackTimes : public Feature
+{
+  TimingSlices   *timing_slices;
+  vector<double>  attack_times;
+
+  AttackTimes (TimingSlices *timing_slices) :
+    Feature ("--attack-times", "compute timestamps for possible note attacks"),
+    timing_slices (timing_slices)
+  {
+  }
+
+  void
+  compute (const Signal &signal)
+  {
+    timing_slices->compute (signal);
+    
+    for (int i = 0; i < timing_slices->n_slices(); i++)
+      attack_times.push_back (timing_slices->spectral_flux (i - 1, i, TimingSlices::SPECTRAL_FLUX_POSITIVE));
+  }
+
+  void
+  print_results() const
+  {
+    print_vector ("attack_times", attack_times);
+    // for (uint i = 0; i < attack_times.size(); i++) // debugging (gnuplot output)
+    //   printf ("%g\n", attack_times[i]);
+  }
+};
+
+struct ReleaseTimes : public Feature
+{
+  TimingSlices   *timing_slices;
+  vector<double>  release_times;
+
+  ReleaseTimes (TimingSlices *timing_slices) :
+    Feature ("--release-times", "compute timestamps for possible note releases"),
+    timing_slices (timing_slices)
+  {
+  }
+
+  void
+  compute (const Signal &signal)
+  {
+    timing_slices->compute (signal);
+    
+    for (int i = 0; i < timing_slices->n_slices(); i++)
+      release_times.push_back (timing_slices->spectral_flux (i - 1, i, TimingSlices::SPECTRAL_FLUX_NEGATIVE));
+  }
+
+  void
+  print_results() const
+  {
+    print_vector ("release_times", release_times);
+    // for (uint i = 0; i < release_times.size(); i++) // debugging (gnuplot output)
+    //  printf ("%g\n", release_times[i]);
+  }
+};
+
+Options::Options () :
+  join_spectrum_slices (1)
 {
   program_name = "bsefextract";
   channel = 0;
+  verbose = false;
   cut_zeros_head = false;
   cut_zeros_tail = false;
   silence_threshold = 0.0;
   base_freq_hint = 0.0;
   focus_center = 50.0;
   focus_width = 100.0;
+  timing_window_stepping_ms = 30;
+  timing_window_size_ms = 50;
   output_file = stdout;
 }
 
 void
-Options::validate_percent (const string& option, gdouble value)
+Options::validate_percent (const string &option,
+                           gdouble       value)
 {
   if (value < 0.0 || value > 100.0)
     {
@@ -991,6 +1287,21 @@ Options::validate_percent (const string& option, gdouble value)
     }
 }
 
+void
+Options::validate_int (const string &option,
+                       int           value,
+		       int           vmin,
+		       int           vmax)
+{
+  if (value < vmin || value > vmax)
+    {
+      fprintf (stderr, "%s: invalid argument `%d' for `%s'\n\n", program_name.c_str(), value, option.c_str());
+      fprintf (stderr, "Valid arguments are between %d and %d.\n", vmin, vmax);
+      fprintf (stderr, "Try `%s --help' for more information.\n", program_name.c_str());
+      exit (1);
+    }
+}
+
 static bool
 check_arg (uint         argc,
            char        *argv[],
@@ -1071,6 +1382,11 @@ Options::parse (int   *argc_p,
 	  printf ("%s %s\n", program_name.c_str(), BST_VERSION);
 	  exit (0);
 	}
+      else if (strcmp (argv[i], "--verbose") == 0)
+	{
+	  verbose = true;
+	  argv[i] = NULL;
+	}
       else if (strcmp (argv[i], "--cut-zeros") == 0)
 	{
 	  cut_zeros_head = cut_zeros_tail = true;
@@ -1105,15 +1421,24 @@ Options::parse (int   *argc_p,
 	    }
 	}
       else if (check_arg (argc, argv, &i, "--silence-threshold", &opt_arg))
-        silence_threshold = atof (opt_arg) / 32767.0;
+        silence_threshold = g_ascii_strtod (opt_arg, NULL) / 32767.0;
       else if (check_arg (argc, argv, &i, "--focus-width", &opt_arg))
-        validate_percent ("--focus-width", focus_width = atof (opt_arg));
+        validate_percent ("--focus-width", focus_width = g_ascii_strtod (opt_arg, NULL));
       else if (check_arg (argc, argv, &i, "--focus-center", &opt_arg))
-        validate_percent ("--focus-center", focus_center = atof (opt_arg));
+	validate_percent ("--focus-center", focus_center = g_ascii_strtod (opt_arg, NULL));
       else if (check_arg (argc, argv, &i, "--base-freq-hint", &opt_arg))
-        base_freq_hint = atof (opt_arg);
+	base_freq_hint = g_ascii_strtod (opt_arg, NULL);
+      else if (check_arg (argc, argv, &i, "--timing-window-size", &opt_arg))
+	timing_window_size_ms = g_ascii_strtod (opt_arg, NULL);
+      else if (check_arg (argc, argv, &i, "--timing-window-stepping", &opt_arg))
+	timing_window_stepping_ms = g_ascii_strtod (opt_arg, NULL);
       else if (check_arg (argc, argv, &i, "--channel", &opt_arg))
-        channel = atoi (opt_arg);
+	channel = atoi (opt_arg);
+      else if (check_arg (argc, argv, &i, "--join-spectrum-slices", &opt_arg))
+	{
+	  join_spectrum_slices = atoi (opt_arg);
+	  validate_int ("--join-spectrum-slices", join_spectrum_slices, 1, 100000);
+	}
       else
         for (list<Feature*>::const_iterator fi = feature_list.begin(); fi != feature_list.end(); fi++)
           if (check_arg (argc, argv, &i, (*fi)->option))
@@ -1155,6 +1480,10 @@ Options::print_usage ()
   fprintf (stderr, " --focus-center=X            center focus region around X%% [50]\n");
   fprintf (stderr, " --focus-width=Y             width of focus region in %% [100]\n");
   fprintf (stderr, " --base-freq-hint            expected base frequency (for the pitch detection)\n");
+  fprintf (stderr, " --join-spectrum-slices=N    when extracting a spectrum, join N 30ms slices\n");
+  fprintf (stderr, " --timing-window-size=N      attack/release detector window size in ms [50]\n");
+  fprintf (stderr, "                             (actual window size may be larger, use --verbose)\n");
+  fprintf (stderr, " --timing-window-stepping=N  attack/release detector stepping in ms [30]\n");
   fprintf (stderr, " -o <output_file>            set the name of a file to write the features to\n");
   fprintf (stderr, "\n");
   fprintf (stderr, "(example: %s --start-time --end-time t.wav).\n", options.program_name.c_str());
@@ -1169,10 +1498,11 @@ print_header (const char *src)
 }
 
 int
-main (int argc, char **argv)
+main (int    argc,
+      char **argv)
 {
   /* init */
-  BirnetInitValue values[] = {
+  SfiInitValue values[] = {
     { "stand-alone",            "true" }, /* no rcfiles etc. */
     { "wave-chunk-padding",     NULL, 1, },
     { "dcache-block-size",      NULL, 8192, },
@@ -1186,6 +1516,7 @@ main (int argc, char **argv)
   ComplexSignalFeature *complex_signal_feature = new ComplexSignalFeature;
   BaseFreqFeature *base_freq_feature = new BaseFreqFeature (complex_signal_feature);
   VolumeFeature *volume_feature = new VolumeFeature (complex_signal_feature);
+  TimingSlices *timing_slices = new TimingSlices;  // not user visible
 
   feature_list.push_back (new StartTimeFeature());
   feature_list.push_back (new EndTimeFeature());
@@ -1193,6 +1524,7 @@ main (int argc, char **argv)
   feature_list.push_back (new AvgSpectrumFeature (spectrum_feature));
   feature_list.push_back (new AvgEnergyFeature());
   feature_list.push_back (new MinMaxPeakFeature());
+  feature_list.push_back (new DCOffsetFeature());
   feature_list.push_back (new RawSignalFeature());
   feature_list.push_back (complex_signal_feature);
   feature_list.push_back (base_freq_feature);
@@ -1201,6 +1533,8 @@ main (int argc, char **argv)
   feature_list.push_back (volume_feature);
   feature_list.push_back (new VolumeSmear (volume_feature));
   feature_list.push_back (new VolumeWobble (volume_feature));
+  feature_list.push_back (new AttackTimes (timing_slices));
+  feature_list.push_back (new ReleaseTimes (timing_slices));
 
   /* parse options */
   options.parse (&argc, &argv);
@@ -1259,7 +1593,7 @@ main (int argc, char **argv)
   print_header (argv[1]);
   for (list<Feature*>::const_iterator fi = feature_list.begin(); fi != feature_list.end(); fi++)
     {
-      const Feature& feature = *(*fi);
+      const Feature &feature = *(*fi);
       if (feature.extract_feature)
 	{
 	  fprintf (options.output_file, "# %s: %s\n", feature.option, feature.description);
